#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zun/criapi/api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zun.criapi import gogo_pb2 as zun_dot_criapi_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14zun/criapi/api.proto\x12\x10runtime.v1alpha2\x1a\x15zun/criapi/gogo.proto\"!\n\x0eVersionRequest\x12\x0f\n\x07version\x18\x01 \x01(\t\"n\n\x0fVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x14\n\x0cruntime_name\x18\x02 \x01(\t\x12\x17\n\x0fruntime_version\x18\x03 \x01(\t\x12\x1b\n\x13runtime_api_version\x18\x04 \x01(\t\"?\n\tDNSConfig\x12\x0f\n\x07servers\x18\x01 \x03(\t\x12\x10\n\x08searches\x18\x02 \x03(\t\x12\x0f\n\x07options\x18\x03 \x03(\t\"w\n\x0bPortMapping\x12,\n\x08protocol\x18\x01 \x01(\x0e\x32\x1a.runtime.v1alpha2.Protocol\x12\x16\n\x0e\x63ontainer_port\x18\x02 \x01(\x05\x12\x11\n\thost_port\x18\x03 \x01(\x05\x12\x0f\n\x07host_ip\x18\x04 \x01(\t\"\x96\x01\n\x05Mount\x12\x16\n\x0e\x63ontainer_path\x18\x01 \x01(\t\x12\x11\n\thost_path\x18\x02 \x01(\t\x12\x10\n\x08readonly\x18\x03 \x01(\x08\x12\x17\n\x0fselinux_relabel\x18\x04 \x01(\x08\x12\x37\n\x0bpropagation\x18\x05 \x01(\x0e\x32\".runtime.v1alpha2.MountPropagation\"B\n\tIDMapping\x12\x0f\n\x07host_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63ontainer_id\x18\x02 \x01(\r\x12\x0e\n\x06length\x18\x03 \x01(\r\"\x94\x01\n\rUserNamespace\x12-\n\x04mode\x18\x01 \x01(\x0e\x32\x1f.runtime.v1alpha2.NamespaceMode\x12)\n\x04uids\x18\x02 \x03(\x0b\x32\x1b.runtime.v1alpha2.IDMapping\x12)\n\x04gids\x18\x03 \x03(\x0b\x32\x1b.runtime.v1alpha2.IDMapping\"\xeb\x01\n\x0fNamespaceOption\x12\x30\n\x07network\x18\x01 \x01(\x0e\x32\x1f.runtime.v1alpha2.NamespaceMode\x12,\n\x03pid\x18\x02 \x01(\x0e\x32\x1f.runtime.v1alpha2.NamespaceMode\x12,\n\x03ipc\x18\x03 \x01(\x0e\x32\x1f.runtime.v1alpha2.NamespaceMode\x12\x11\n\ttarget_id\x18\x04 \x01(\t\x12\x37\n\x0euserns_options\x18\x05 \x01(\x0b\x32\x1f.runtime.v1alpha2.UserNamespace\"\x1b\n\nInt64Value\x12\r\n\x05value\x18\x01 \x01(\x03\"\xd1\x03\n\x1bLinuxSandboxSecurityContext\x12<\n\x11namespace_options\x18\x01 \x01(\x0b\x32!.runtime.v1alpha2.NamespaceOption\x12\x38\n\x0fselinux_options\x18\x02 \x01(\x0b\x32\x1f.runtime.v1alpha2.SELinuxOption\x12\x31\n\x0brun_as_user\x18\x03 \x01(\x0b\x32\x1c.runtime.v1alpha2.Int64Value\x12\x32\n\x0crun_as_group\x18\x08 \x01(\x0b\x32\x1c.runtime.v1alpha2.Int64Value\x12\x17\n\x0freadonly_rootfs\x18\x04 \x01(\x08\x12\x1b\n\x13supplemental_groups\x18\x05 \x03(\x03\x12\x12\n\nprivileged\x18\x06 \x01(\x08\x12\x32\n\x07seccomp\x18\t \x01(\x0b\x32!.runtime.v1alpha2.SecurityProfile\x12\x33\n\x08\x61pparmor\x18\n \x01(\x0b\x32!.runtime.v1alpha2.SecurityProfile\x12 \n\x14seccomp_profile_path\x18\x07 \x01(\tB\x02\x18\x01\"\xaf\x01\n\x0fSecurityProfile\x12\x43\n\x0cprofile_type\x18\x01 \x01(\x0e\x32-.runtime.v1alpha2.SecurityProfile.ProfileType\x12\x15\n\rlocalhost_ref\x18\x02 \x01(\t\"@\n\x0bProfileType\x12\x12\n\x0eRuntimeDefault\x10\x00\x12\x0e\n\nUnconfined\x10\x01\x12\r\n\tLocalhost\x10\x02\"\xe9\x02\n\x15LinuxPodSandboxConfig\x12\x15\n\rcgroup_parent\x18\x01 \x01(\t\x12G\n\x10security_context\x18\x02 \x01(\x0b\x32-.runtime.v1alpha2.LinuxSandboxSecurityContext\x12\x45\n\x07sysctls\x18\x03 \x03(\x0b\x32\x34.runtime.v1alpha2.LinuxPodSandboxConfig.SysctlsEntry\x12;\n\x08overhead\x18\x04 \x01(\x0b\x32).runtime.v1alpha2.LinuxContainerResources\x12<\n\tresources\x18\x05 \x01(\x0b\x32).runtime.v1alpha2.LinuxContainerResources\x1a.\n\x0cSysctlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n\x12PodSandboxMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07\x61ttempt\x18\x04 \x01(\r\"\xbb\x04\n\x10PodSandboxConfig\x12\x36\n\x08metadata\x18\x01 \x01(\x0b\x32$.runtime.v1alpha2.PodSandboxMetadata\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x15\n\rlog_directory\x18\x03 \x01(\t\x12/\n\ndns_config\x18\x04 \x01(\x0b\x32\x1b.runtime.v1alpha2.DNSConfig\x12\x34\n\rport_mappings\x18\x05 \x03(\x0b\x32\x1d.runtime.v1alpha2.PortMapping\x12>\n\x06labels\x18\x06 \x03(\x0b\x32..runtime.v1alpha2.PodSandboxConfig.LabelsEntry\x12H\n\x0b\x61nnotations\x18\x07 \x03(\x0b\x32\x33.runtime.v1alpha2.PodSandboxConfig.AnnotationsEntry\x12\x36\n\x05linux\x18\x08 \x01(\x0b\x32\'.runtime.v1alpha2.LinuxPodSandboxConfig\x12:\n\x07windows\x18\t \x01(\x0b\x32).runtime.v1alpha2.WindowsPodSandboxConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n\x14RunPodSandboxRequest\x12\x32\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\".runtime.v1alpha2.PodSandboxConfig\x12\x17\n\x0fruntime_handler\x18\x02 \x01(\t\"/\n\x15RunPodSandboxResponse\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\"/\n\x15StopPodSandboxRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\"\x18\n\x16StopPodSandboxResponse\"1\n\x17RemovePodSandboxRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\"\x1a\n\x18RemovePodSandboxResponse\"B\n\x17PodSandboxStatusRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\x12\x0f\n\x07verbose\x18\x02 \x01(\x08\"\x13\n\x05PodIP\x12\n\n\x02ip\x18\x01 \x01(\t\"V\n\x17PodSandboxNetworkStatus\x12\n\n\x02ip\x18\x01 \x01(\t\x12/\n\x0e\x61\x64\x64itional_ips\x18\x02 \x03(\x0b\x32\x17.runtime.v1alpha2.PodIP\"?\n\tNamespace\x12\x32\n\x07options\x18\x02 \x01(\x0b\x32!.runtime.v1alpha2.NamespaceOption\"H\n\x15LinuxPodSandboxStatus\x12/\n\nnamespaces\x18\x01 \x01(\x0b\x32\x1b.runtime.v1alpha2.Namespace\"\x96\x04\n\x10PodSandboxStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x08metadata\x18\x02 \x01(\x0b\x32$.runtime.v1alpha2.PodSandboxMetadata\x12\x30\n\x05state\x18\x03 \x01(\x0e\x32!.runtime.v1alpha2.PodSandboxState\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12:\n\x07network\x18\x05 \x01(\x0b\x32).runtime.v1alpha2.PodSandboxNetworkStatus\x12\x36\n\x05linux\x18\x06 \x01(\x0b\x32\'.runtime.v1alpha2.LinuxPodSandboxStatus\x12>\n\x06labels\x18\x07 \x03(\x0b\x32..runtime.v1alpha2.PodSandboxStatus.LabelsEntry\x12H\n\x0b\x61nnotations\x18\x08 \x03(\x0b\x32\x33.runtime.v1alpha2.PodSandboxStatus.AnnotationsEntry\x12\x17\n\x0fruntime_handler\x18\t \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x01\n\x18PodSandboxStatusResponse\x12\x32\n\x06status\x18\x01 \x01(\x0b\x32\".runtime.v1alpha2.PodSandboxStatus\x12\x42\n\x04info\x18\x02 \x03(\x0b\x32\x34.runtime.v1alpha2.PodSandboxStatusResponse.InfoEntry\x1a+\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x14PodSandboxStateValue\x12\x30\n\x05state\x18\x01 \x01(\x0e\x32!.runtime.v1alpha2.PodSandboxState\"\xda\x01\n\x10PodSandboxFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x35\n\x05state\x18\x02 \x01(\x0b\x32&.runtime.v1alpha2.PodSandboxStateValue\x12M\n\x0elabel_selector\x18\x03 \x03(\x0b\x32\x35.runtime.v1alpha2.PodSandboxFilter.LabelSelectorEntry\x1a\x34\n\x12LabelSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"K\n\x15ListPodSandboxRequest\x12\x32\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\".runtime.v1alpha2.PodSandboxFilter\"\x90\x03\n\nPodSandbox\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x08metadata\x18\x02 \x01(\x0b\x32$.runtime.v1alpha2.PodSandboxMetadata\x12\x30\n\x05state\x18\x03 \x01(\x0e\x32!.runtime.v1alpha2.PodSandboxState\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x38\n\x06labels\x18\x05 \x03(\x0b\x32(.runtime.v1alpha2.PodSandbox.LabelsEntry\x12\x42\n\x0b\x61nnotations\x18\x06 \x03(\x0b\x32-.runtime.v1alpha2.PodSandbox.AnnotationsEntry\x12\x17\n\x0fruntime_handler\x18\x07 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\x16ListPodSandboxResponse\x12+\n\x05items\x18\x01 \x03(\x0b\x32\x1c.runtime.v1alpha2.PodSandbox\"0\n\x16PodSandboxStatsRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\"K\n\x17PodSandboxStatsResponse\x12\x30\n\x05stats\x18\x01 \x01(\x0b\x32!.runtime.v1alpha2.PodSandboxStats\"\xad\x01\n\x15PodSandboxStatsFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12R\n\x0elabel_selector\x18\x02 \x03(\x0b\x32:.runtime.v1alpha2.PodSandboxStatsFilter.LabelSelectorEntry\x1a\x34\n\x12LabelSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x1aListPodSandboxStatsRequest\x12\x37\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\'.runtime.v1alpha2.PodSandboxStatsFilter\"O\n\x1bListPodSandboxStatsResponse\x12\x30\n\x05stats\x18\x01 \x03(\x0b\x32!.runtime.v1alpha2.PodSandboxStats\"\xcf\x02\n\x14PodSandboxAttributes\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x08metadata\x18\x02 \x01(\x0b\x32$.runtime.v1alpha2.PodSandboxMetadata\x12\x42\n\x06labels\x18\x03 \x03(\x0b\x32\x32.runtime.v1alpha2.PodSandboxAttributes.LabelsEntry\x12L\n\x0b\x61nnotations\x18\x04 \x03(\x0b\x32\x37.runtime.v1alpha2.PodSandboxAttributes.AnnotationsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x01\n\x0fPodSandboxStats\x12:\n\nattributes\x18\x01 \x01(\x0b\x32&.runtime.v1alpha2.PodSandboxAttributes\x12\x35\n\x05linux\x18\x02 \x01(\x0b\x32&.runtime.v1alpha2.LinuxPodSandboxStats\x12\x39\n\x07windows\x18\x03 \x01(\x0b\x32(.runtime.v1alpha2.WindowsPodSandboxStats\"\x86\x02\n\x14LinuxPodSandboxStats\x12\'\n\x03\x63pu\x18\x01 \x01(\x0b\x32\x1a.runtime.v1alpha2.CpuUsage\x12-\n\x06memory\x18\x02 \x01(\x0b\x32\x1d.runtime.v1alpha2.MemoryUsage\x12/\n\x07network\x18\x03 \x01(\x0b\x32\x1e.runtime.v1alpha2.NetworkUsage\x12/\n\x07process\x18\x04 \x01(\x0b\x32\x1e.runtime.v1alpha2.ProcessUsage\x12\x34\n\ncontainers\x18\x05 \x03(\x0b\x32 .runtime.v1alpha2.ContainerStats\"\x18\n\x16WindowsPodSandboxStats\"\xa2\x01\n\x0cNetworkUsage\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x42\n\x11\x64\x65\x66\x61ult_interface\x18\x02 \x01(\x0b\x32\'.runtime.v1alpha2.NetworkInterfaceUsage\x12;\n\ninterfaces\x18\x03 \x03(\x0b\x32\'.runtime.v1alpha2.NetworkInterfaceUsage\"\xeb\x01\n\x15NetworkInterfaceUsage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x08rx_bytes\x18\x02 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12\x30\n\trx_errors\x18\x03 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12/\n\x08tx_bytes\x18\x04 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12\x30\n\ttx_errors\x18\x05 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\"W\n\x0cProcessUsage\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x34\n\rprocess_count\x18\x02 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\"\x91\x01\n\tImageSpec\x12\r\n\x05image\x18\x01 \x01(\t\x12\x41\n\x0b\x61nnotations\x18\x02 \x03(\x0b\x32,.runtime.v1alpha2.ImageSpec.AnnotationsEntry\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"&\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x8b\x03\n\x17LinuxContainerResources\x12\x12\n\ncpu_period\x18\x01 \x01(\x03\x12\x11\n\tcpu_quota\x18\x02 \x01(\x03\x12\x12\n\ncpu_shares\x18\x03 \x01(\x03\x12\x1d\n\x15memory_limit_in_bytes\x18\x04 \x01(\x03\x12\x15\n\room_score_adj\x18\x05 \x01(\x03\x12\x13\n\x0b\x63puset_cpus\x18\x06 \x01(\t\x12\x13\n\x0b\x63puset_mems\x18\x07 \x01(\t\x12\x38\n\x0fhugepage_limits\x18\x08 \x03(\x0b\x32\x1f.runtime.v1alpha2.HugepageLimit\x12G\n\x07unified\x18\t \x03(\x0b\x32\x36.runtime.v1alpha2.LinuxContainerResources.UnifiedEntry\x12\"\n\x1amemory_swap_limit_in_bytes\x18\n \x01(\x03\x1a.\n\x0cUnifiedEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\rHugepageLimit\x12\x11\n\tpage_size\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\"H\n\rSELinuxOption\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\"c\n\nCapability\x12\x18\n\x10\x61\x64\x64_capabilities\x18\x01 \x03(\t\x12\x19\n\x11\x64rop_capabilities\x18\x02 \x03(\t\x12 \n\x18\x61\x64\x64_ambient_capabilities\x18\x03 \x03(\t\"\x82\x05\n\x1dLinuxContainerSecurityContext\x12\x32\n\x0c\x63\x61pabilities\x18\x01 \x01(\x0b\x32\x1c.runtime.v1alpha2.Capability\x12\x12\n\nprivileged\x18\x02 \x01(\x08\x12<\n\x11namespace_options\x18\x03 \x01(\x0b\x32!.runtime.v1alpha2.NamespaceOption\x12\x38\n\x0fselinux_options\x18\x04 \x01(\x0b\x32\x1f.runtime.v1alpha2.SELinuxOption\x12\x31\n\x0brun_as_user\x18\x05 \x01(\x0b\x32\x1c.runtime.v1alpha2.Int64Value\x12\x32\n\x0crun_as_group\x18\x0c \x01(\x0b\x32\x1c.runtime.v1alpha2.Int64Value\x12\x17\n\x0frun_as_username\x18\x06 \x01(\t\x12\x17\n\x0freadonly_rootfs\x18\x07 \x01(\x08\x12\x1b\n\x13supplemental_groups\x18\x08 \x03(\x03\x12\x14\n\x0cno_new_privs\x18\x0b \x01(\x08\x12\x14\n\x0cmasked_paths\x18\r \x03(\t\x12\x16\n\x0ereadonly_paths\x18\x0e \x03(\t\x12\x32\n\x07seccomp\x18\x0f \x01(\x0b\x32!.runtime.v1alpha2.SecurityProfile\x12\x33\n\x08\x61pparmor\x18\x10 \x01(\x0b\x32!.runtime.v1alpha2.SecurityProfile\x12\x1c\n\x10\x61pparmor_profile\x18\t \x01(\tB\x02\x18\x01\x12 \n\x14seccomp_profile_path\x18\n \x01(\tB\x02\x18\x01\"\x9f\x01\n\x14LinuxContainerConfig\x12<\n\tresources\x18\x01 \x01(\x0b\x32).runtime.v1alpha2.LinuxContainerResources\x12I\n\x10security_context\x18\x02 \x01(\x0b\x32/.runtime.v1alpha2.LinuxContainerSecurityContext\"g\n\x1dWindowsSandboxSecurityContext\x12\x17\n\x0frun_as_username\x18\x01 \x01(\t\x12\x17\n\x0f\x63redential_spec\x18\x02 \x01(\t\x12\x14\n\x0chost_process\x18\x03 \x01(\x08\"d\n\x17WindowsPodSandboxConfig\x12I\n\x10security_context\x18\x01 \x01(\x0b\x32/.runtime.v1alpha2.WindowsSandboxSecurityContext\"i\n\x1fWindowsContainerSecurityContext\x12\x17\n\x0frun_as_username\x18\x01 \x01(\t\x12\x17\n\x0f\x63redential_spec\x18\x02 \x01(\t\x12\x14\n\x0chost_process\x18\x03 \x01(\x08\"\xa5\x01\n\x16WindowsContainerConfig\x12>\n\tresources\x18\x01 \x01(\x0b\x32+.runtime.v1alpha2.WindowsContainerResources\x12K\n\x10security_context\x18\x02 \x01(\x0b\x32\x31.runtime.v1alpha2.WindowsContainerSecurityContext\"\x94\x01\n\x19WindowsContainerResources\x12\x12\n\ncpu_shares\x18\x01 \x01(\x03\x12\x11\n\tcpu_count\x18\x02 \x01(\x03\x12\x13\n\x0b\x63pu_maximum\x18\x03 \x01(\x03\x12\x1d\n\x15memory_limit_in_bytes\x18\x04 \x01(\x03\x12\x1c\n\x14rootfs_size_in_bytes\x18\x05 \x01(\x03\"2\n\x11\x43ontainerMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61ttempt\x18\x02 \x01(\r\"H\n\x06\x44\x65vice\x12\x16\n\x0e\x63ontainer_path\x18\x01 \x01(\t\x12\x11\n\thost_path\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x01(\t\"\xc5\x05\n\x0f\x43ontainerConfig\x12\x35\n\x08metadata\x18\x01 \x01(\x0b\x32#.runtime.v1alpha2.ContainerMetadata\x12*\n\x05image\x18\x02 \x01(\x0b\x32\x1b.runtime.v1alpha2.ImageSpec\x12\x0f\n\x07\x63ommand\x18\x03 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x04 \x03(\t\x12\x13\n\x0bworking_dir\x18\x05 \x01(\t\x12(\n\x04\x65nvs\x18\x06 \x03(\x0b\x32\x1a.runtime.v1alpha2.KeyValue\x12\'\n\x06mounts\x18\x07 \x03(\x0b\x32\x17.runtime.v1alpha2.Mount\x12)\n\x07\x64\x65vices\x18\x08 \x03(\x0b\x32\x18.runtime.v1alpha2.Device\x12=\n\x06labels\x18\t \x03(\x0b\x32-.runtime.v1alpha2.ContainerConfig.LabelsEntry\x12G\n\x0b\x61nnotations\x18\n \x03(\x0b\x32\x32.runtime.v1alpha2.ContainerConfig.AnnotationsEntry\x12\x10\n\x08log_path\x18\x0b \x01(\t\x12\r\n\x05stdin\x18\x0c \x01(\x08\x12\x12\n\nstdin_once\x18\r \x01(\x08\x12\x0b\n\x03tty\x18\x0e \x01(\x08\x12\x35\n\x05linux\x18\x0f \x01(\x0b\x32&.runtime.v1alpha2.LinuxContainerConfig\x12\x39\n\x07windows\x18\x10 \x01(\x0b\x32(.runtime.v1alpha2.WindowsContainerConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9f\x01\n\x16\x43reateContainerRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32!.runtime.v1alpha2.ContainerConfig\x12:\n\x0esandbox_config\x18\x03 \x01(\x0b\x32\".runtime.v1alpha2.PodSandboxConfig\"/\n\x17\x43reateContainerResponse\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"-\n\x15StartContainerRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"\x18\n\x16StartContainerResponse\"=\n\x14StopContainerRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\x03\"\x17\n\x15StopContainerResponse\".\n\x16RemoveContainerRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"\x19\n\x17RemoveContainerResponse\"F\n\x13\x43ontainerStateValue\x12/\n\x05state\x18\x01 \x01(\x0e\x32 .runtime.v1alpha2.ContainerState\"\xef\x01\n\x0f\x43ontainerFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x05state\x18\x02 \x01(\x0b\x32%.runtime.v1alpha2.ContainerStateValue\x12\x16\n\x0epod_sandbox_id\x18\x03 \x01(\t\x12L\n\x0elabel_selector\x18\x04 \x03(\x0b\x32\x34.runtime.v1alpha2.ContainerFilter.LabelSelectorEntry\x1a\x34\n\x12LabelSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n\x15ListContainersRequest\x12\x31\n\x06\x66ilter\x18\x01 \x01(\x0b\x32!.runtime.v1alpha2.ContainerFilter\"\xc9\x03\n\tContainer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0epod_sandbox_id\x18\x02 \x01(\t\x12\x35\n\x08metadata\x18\x03 \x01(\x0b\x32#.runtime.v1alpha2.ContainerMetadata\x12*\n\x05image\x18\x04 \x01(\x0b\x32\x1b.runtime.v1alpha2.ImageSpec\x12\x11\n\timage_ref\x18\x05 \x01(\t\x12/\n\x05state\x18\x06 \x01(\x0e\x32 .runtime.v1alpha2.ContainerState\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12\x37\n\x06labels\x18\x08 \x03(\x0b\x32\'.runtime.v1alpha2.Container.LabelsEntry\x12\x41\n\x0b\x61nnotations\x18\t \x03(\x0b\x32,.runtime.v1alpha2.Container.AnnotationsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x16ListContainersResponse\x12/\n\ncontainers\x18\x01 \x03(\x0b\x32\x1b.runtime.v1alpha2.Container\"?\n\x16\x43ontainerStatusRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x0f\n\x07verbose\x18\x02 \x01(\x08\"\xdb\x04\n\x0f\x43ontainerStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x35\n\x08metadata\x18\x02 \x01(\x0b\x32#.runtime.v1alpha2.ContainerMetadata\x12/\n\x05state\x18\x03 \x01(\x0e\x32 .runtime.v1alpha2.ContainerState\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x12\n\nstarted_at\x18\x05 \x01(\x03\x12\x13\n\x0b\x66inished_at\x18\x06 \x01(\x03\x12\x11\n\texit_code\x18\x07 \x01(\x05\x12*\n\x05image\x18\x08 \x01(\x0b\x32\x1b.runtime.v1alpha2.ImageSpec\x12\x11\n\timage_ref\x18\t \x01(\t\x12\x0e\n\x06reason\x18\n \x01(\t\x12\x0f\n\x07message\x18\x0b \x01(\t\x12=\n\x06labels\x18\x0c \x03(\x0b\x32-.runtime.v1alpha2.ContainerStatus.LabelsEntry\x12G\n\x0b\x61nnotations\x18\r \x03(\x0b\x32\x32.runtime.v1alpha2.ContainerStatus.AnnotationsEntry\x12\'\n\x06mounts\x18\x0e \x03(\x0b\x32\x17.runtime.v1alpha2.Mount\x12\x10\n\x08log_path\x18\x0f \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x01\n\x17\x43ontainerStatusResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.runtime.v1alpha2.ContainerStatus\x12\x41\n\x04info\x18\x02 \x03(\x0b\x32\x33.runtime.v1alpha2.ContainerStatusResponse.InfoEntry\x1a+\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbc\x02\n\x1fUpdateContainerResourcesRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x38\n\x05linux\x18\x02 \x01(\x0b\x32).runtime.v1alpha2.LinuxContainerResources\x12<\n\x07windows\x18\x03 \x01(\x0b\x32+.runtime.v1alpha2.WindowsContainerResources\x12W\n\x0b\x61nnotations\x18\x04 \x03(\x0b\x32\x42.runtime.v1alpha2.UpdateContainerResourcesRequest.AnnotationsEntry\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\"\n UpdateContainerResourcesResponse\"E\n\x0f\x45xecSyncRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x03(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\"E\n\x10\x45xecSyncResponse\x12\x0e\n\x06stdout\x18\x01 \x01(\x0c\x12\x0e\n\x06stderr\x18\x02 \x01(\x0c\x12\x11\n\texit_code\x18\x03 \x01(\x05\"l\n\x0b\x45xecRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x03(\t\x12\x0b\n\x03tty\x18\x03 \x01(\x08\x12\r\n\x05stdin\x18\x04 \x01(\x08\x12\x0e\n\x06stdout\x18\x05 \x01(\x08\x12\x0e\n\x06stderr\x18\x06 \x01(\x08\"\x1b\n\x0c\x45xecResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\"a\n\rAttachRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\r\n\x05stdin\x18\x02 \x01(\x08\x12\x0b\n\x03tty\x18\x03 \x01(\x08\x12\x0e\n\x06stdout\x18\x04 \x01(\x08\x12\x0e\n\x06stderr\x18\x05 \x01(\x08\"\x1d\n\x0e\x41ttachResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\":\n\x12PortForwardRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x03(\x05\"\"\n\x13PortForwardResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\"9\n\x0bImageFilter\x12*\n\x05image\x18\x01 \x01(\x0b\x32\x1b.runtime.v1alpha2.ImageSpec\"B\n\x11ListImagesRequest\x12-\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1d.runtime.v1alpha2.ImageFilter\"\xc2\x01\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\trepo_tags\x18\x02 \x03(\t\x12\x14\n\x0crepo_digests\x18\x03 \x03(\t\x12\x0c\n\x04size\x18\x04 \x01(\x04\x12)\n\x03uid\x18\x05 \x01(\x0b\x32\x1c.runtime.v1alpha2.Int64Value\x12\x10\n\x08username\x18\x06 \x01(\t\x12)\n\x04spec\x18\x07 \x01(\x0b\x32\x1b.runtime.v1alpha2.ImageSpec\x12\x0e\n\x06pinned\x18\x08 \x01(\x08\"=\n\x12ListImagesResponse\x12\'\n\x06images\x18\x01 \x03(\x0b\x32\x17.runtime.v1alpha2.Image\"Q\n\x12ImageStatusRequest\x12*\n\x05image\x18\x01 \x01(\x0b\x32\x1b.runtime.v1alpha2.ImageSpec\x12\x0f\n\x07verbose\x18\x02 \x01(\x08\"\xa9\x01\n\x13ImageStatusResponse\x12&\n\x05image\x18\x01 \x01(\x0b\x32\x17.runtime.v1alpha2.Image\x12=\n\x04info\x18\x02 \x03(\x0b\x32/.runtime.v1alpha2.ImageStatusResponse.InfoEntry\x1a+\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\nAuthConfig\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04\x61uth\x18\x03 \x01(\t\x12\x16\n\x0eserver_address\x18\x04 \x01(\t\x12\x16\n\x0eidentity_token\x18\x05 \x01(\t\x12\x16\n\x0eregistry_token\x18\x06 \x01(\t\"\xa6\x01\n\x10PullImageRequest\x12*\n\x05image\x18\x01 \x01(\x0b\x32\x1b.runtime.v1alpha2.ImageSpec\x12*\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x1c.runtime.v1alpha2.AuthConfig\x12:\n\x0esandbox_config\x18\x03 \x01(\x0b\x32\".runtime.v1alpha2.PodSandboxConfig\"&\n\x11PullImageResponse\x12\x11\n\timage_ref\x18\x01 \x01(\t\"@\n\x12RemoveImageRequest\x12*\n\x05image\x18\x01 \x01(\x0b\x32\x1b.runtime.v1alpha2.ImageSpec\"\x15\n\x13RemoveImageResponse\"!\n\rNetworkConfig\x12\x10\n\x08pod_cidr\x18\x01 \x01(\t\"H\n\rRuntimeConfig\x12\x37\n\x0enetwork_config\x18\x01 \x01(\x0b\x32\x1f.runtime.v1alpha2.NetworkConfig\"U\n\x1aUpdateRuntimeConfigRequest\x12\x37\n\x0eruntime_config\x18\x01 \x01(\x0b\x32\x1f.runtime.v1alpha2.RuntimeConfig\"\x1d\n\x1bUpdateRuntimeConfigResponse\"Q\n\x10RuntimeCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"G\n\rRuntimeStatus\x12\x36\n\nconditions\x18\x01 \x03(\x0b\x32\".runtime.v1alpha2.RuntimeCondition\" \n\rStatusRequest\x12\x0f\n\x07verbose\x18\x01 \x01(\x08\"\xa8\x01\n\x0eStatusResponse\x12/\n\x06status\x18\x01 \x01(\x0b\x32\x1f.runtime.v1alpha2.RuntimeStatus\x12\x38\n\x04info\x18\x02 \x03(\x0b\x32*.runtime.v1alpha2.StatusResponse.InfoEntry\x1a+\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x14\n\x12ImageFsInfoRequest\"\x1c\n\x0bUInt64Value\x12\r\n\x05value\x18\x01 \x01(\x04\"*\n\x14\x46ilesystemIdentifier\x12\x12\n\nmountpoint\x18\x01 \x01(\t\"\xc2\x01\n\x0f\x46ilesystemUsage\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x35\n\x05\x66s_id\x18\x02 \x01(\x0b\x32&.runtime.v1alpha2.FilesystemIdentifier\x12\x31\n\nused_bytes\x18\x03 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12\x32\n\x0binodes_used\x18\x04 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\"S\n\x13ImageFsInfoResponse\x12<\n\x11image_filesystems\x18\x01 \x03(\x0b\x32!.runtime.v1alpha2.FilesystemUsage\"-\n\x15\x43ontainerStatsRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"I\n\x16\x43ontainerStatsResponse\x12/\n\x05stats\x18\x01 \x01(\x0b\x32 .runtime.v1alpha2.ContainerStats\"S\n\x19ListContainerStatsRequest\x12\x36\n\x06\x66ilter\x18\x01 \x01(\x0b\x32&.runtime.v1alpha2.ContainerStatsFilter\"\xc3\x01\n\x14\x43ontainerStatsFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0epod_sandbox_id\x18\x02 \x01(\t\x12Q\n\x0elabel_selector\x18\x03 \x03(\x0b\x32\x39.runtime.v1alpha2.ContainerStatsFilter.LabelSelectorEntry\x1a\x34\n\x12LabelSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"M\n\x1aListContainerStatsResponse\x12/\n\x05stats\x18\x01 \x03(\x0b\x32 .runtime.v1alpha2.ContainerStats\"\xcb\x02\n\x13\x43ontainerAttributes\x12\n\n\x02id\x18\x01 \x01(\t\x12\x35\n\x08metadata\x18\x02 \x01(\x0b\x32#.runtime.v1alpha2.ContainerMetadata\x12\x41\n\x06labels\x18\x03 \x03(\x0b\x32\x31.runtime.v1alpha2.ContainerAttributes.LabelsEntry\x12K\n\x0b\x61nnotations\x18\x04 \x03(\x0b\x32\x36.runtime.v1alpha2.ContainerAttributes.AnnotationsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xde\x01\n\x0e\x43ontainerStats\x12\x39\n\nattributes\x18\x01 \x01(\x0b\x32%.runtime.v1alpha2.ContainerAttributes\x12\'\n\x03\x63pu\x18\x02 \x01(\x0b\x32\x1a.runtime.v1alpha2.CpuUsage\x12-\n\x06memory\x18\x03 \x01(\x0b\x32\x1d.runtime.v1alpha2.MemoryUsage\x12\x39\n\x0ewritable_layer\x18\x04 \x01(\x0b\x32!.runtime.v1alpha2.FilesystemUsage\"\x96\x01\n\x08\x43puUsage\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12>\n\x17usage_core_nano_seconds\x18\x02 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12\x37\n\x10usage_nano_cores\x18\x03 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\"\xe6\x02\n\x0bMemoryUsage\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x38\n\x11working_set_bytes\x18\x02 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12\x36\n\x0f\x61vailable_bytes\x18\x03 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12\x32\n\x0busage_bytes\x18\x04 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12\x30\n\trss_bytes\x18\x05 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12\x32\n\x0bpage_faults\x18\x06 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\x12\x38\n\x11major_page_faults\x18\x07 \x01(\x0b\x32\x1d.runtime.v1alpha2.UInt64Value\"1\n\x19ReopenContainerLogRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"\x1c\n\x1aReopenContainerLogResponse*&\n\x08Protocol\x12\x07\n\x03TCP\x10\x00\x12\x07\n\x03UDP\x10\x01\x12\x08\n\x04SCTP\x10\x02*m\n\x10MountPropagation\x12\x17\n\x13PROPAGATION_PRIVATE\x10\x00\x12!\n\x1dPROPAGATION_HOST_TO_CONTAINER\x10\x01\x12\x1d\n\x19PROPAGATION_BIDIRECTIONAL\x10\x02*=\n\rNamespaceMode\x12\x07\n\x03POD\x10\x00\x12\r\n\tCONTAINER\x10\x01\x12\x08\n\x04NODE\x10\x02\x12\n\n\x06TARGET\x10\x03*:\n\x0fPodSandboxState\x12\x11\n\rSANDBOX_READY\x10\x00\x12\x14\n\x10SANDBOX_NOTREADY\x10\x01*k\n\x0e\x43ontainerState\x12\x15\n\x11\x43ONTAINER_CREATED\x10\x00\x12\x15\n\x11\x43ONTAINER_RUNNING\x10\x01\x12\x14\n\x10\x43ONTAINER_EXITED\x10\x02\x12\x15\n\x11\x43ONTAINER_UNKNOWN\x10\x03\x32\xa1\x13\n\x0eRuntimeService\x12P\n\x07Version\x12 .runtime.v1alpha2.VersionRequest\x1a!.runtime.v1alpha2.VersionResponse\"\x00\x12\x62\n\rRunPodSandbox\x12&.runtime.v1alpha2.RunPodSandboxRequest\x1a\'.runtime.v1alpha2.RunPodSandboxResponse\"\x00\x12\x65\n\x0eStopPodSandbox\x12\'.runtime.v1alpha2.StopPodSandboxRequest\x1a(.runtime.v1alpha2.StopPodSandboxResponse\"\x00\x12k\n\x10RemovePodSandbox\x12).runtime.v1alpha2.RemovePodSandboxRequest\x1a*.runtime.v1alpha2.RemovePodSandboxResponse\"\x00\x12k\n\x10PodSandboxStatus\x12).runtime.v1alpha2.PodSandboxStatusRequest\x1a*.runtime.v1alpha2.PodSandboxStatusResponse\"\x00\x12\x65\n\x0eListPodSandbox\x12\'.runtime.v1alpha2.ListPodSandboxRequest\x1a(.runtime.v1alpha2.ListPodSandboxResponse\"\x00\x12h\n\x0f\x43reateContainer\x12(.runtime.v1alpha2.CreateContainerRequest\x1a).runtime.v1alpha2.CreateContainerResponse\"\x00\x12\x65\n\x0eStartContainer\x12\'.runtime.v1alpha2.StartContainerRequest\x1a(.runtime.v1alpha2.StartContainerResponse\"\x00\x12\x62\n\rStopContainer\x12&.runtime.v1alpha2.StopContainerRequest\x1a\'.runtime.v1alpha2.StopContainerResponse\"\x00\x12h\n\x0fRemoveContainer\x12(.runtime.v1alpha2.RemoveContainerRequest\x1a).runtime.v1alpha2.RemoveContainerResponse\"\x00\x12\x65\n\x0eListContainers\x12\'.runtime.v1alpha2.ListContainersRequest\x1a(.runtime.v1alpha2.ListContainersResponse\"\x00\x12h\n\x0f\x43ontainerStatus\x12(.runtime.v1alpha2.ContainerStatusRequest\x1a).runtime.v1alpha2.ContainerStatusResponse\"\x00\x12\x83\x01\n\x18UpdateContainerResources\x12\x31.runtime.v1alpha2.UpdateContainerResourcesRequest\x1a\x32.runtime.v1alpha2.UpdateContainerResourcesResponse\"\x00\x12q\n\x12ReopenContainerLog\x12+.runtime.v1alpha2.ReopenContainerLogRequest\x1a,.runtime.v1alpha2.ReopenContainerLogResponse\"\x00\x12S\n\x08\x45xecSync\x12!.runtime.v1alpha2.ExecSyncRequest\x1a\".runtime.v1alpha2.ExecSyncResponse\"\x00\x12G\n\x04\x45xec\x12\x1d.runtime.v1alpha2.ExecRequest\x1a\x1e.runtime.v1alpha2.ExecResponse\"\x00\x12M\n\x06\x41ttach\x12\x1f.runtime.v1alpha2.AttachRequest\x1a .runtime.v1alpha2.AttachResponse\"\x00\x12\\\n\x0bPortForward\x12$.runtime.v1alpha2.PortForwardRequest\x1a%.runtime.v1alpha2.PortForwardResponse\"\x00\x12\x65\n\x0e\x43ontainerStats\x12\'.runtime.v1alpha2.ContainerStatsRequest\x1a(.runtime.v1alpha2.ContainerStatsResponse\"\x00\x12q\n\x12ListContainerStats\x12+.runtime.v1alpha2.ListContainerStatsRequest\x1a,.runtime.v1alpha2.ListContainerStatsResponse\"\x00\x12h\n\x0fPodSandboxStats\x12(.runtime.v1alpha2.PodSandboxStatsRequest\x1a).runtime.v1alpha2.PodSandboxStatsResponse\"\x00\x12t\n\x13ListPodSandboxStats\x12,.runtime.v1alpha2.ListPodSandboxStatsRequest\x1a-.runtime.v1alpha2.ListPodSandboxStatsResponse\"\x00\x12t\n\x13UpdateRuntimeConfig\x12,.runtime.v1alpha2.UpdateRuntimeConfigRequest\x1a-.runtime.v1alpha2.UpdateRuntimeConfigResponse\"\x00\x12M\n\x06Status\x12\x1f.runtime.v1alpha2.StatusRequest\x1a .runtime.v1alpha2.StatusResponse\"\x00\x32\xdb\x03\n\x0cImageService\x12Y\n\nListImages\x12#.runtime.v1alpha2.ListImagesRequest\x1a$.runtime.v1alpha2.ListImagesResponse\"\x00\x12\\\n\x0bImageStatus\x12$.runtime.v1alpha2.ImageStatusRequest\x1a%.runtime.v1alpha2.ImageStatusResponse\"\x00\x12V\n\tPullImage\x12\".runtime.v1alpha2.PullImageRequest\x1a#.runtime.v1alpha2.PullImageResponse\"\x00\x12\\\n\x0bRemoveImage\x12$.runtime.v1alpha2.RemoveImageRequest\x1a%.runtime.v1alpha2.RemoveImageResponse\"\x00\x12\\\n\x0bImageFsInfo\x12$.runtime.v1alpha2.ImageFsInfoRequest\x1a%.runtime.v1alpha2.ImageFsInfoResponse\"\x00\x42\x46Z(k8s.io/cri-api/pkg/apis/runtime/v1alpha2\xd8\xe1\x1e\x00\x80\xe2\x1e\x01\xc8\xe1\x1e\x01\xc8\xe2\x1e\x01\xe0\xe2\x1e\x01\xd0\xe2\x1e\x01\x90\xe3\x1e\x00\x62\x06proto3')

_PROTOCOL = DESCRIPTOR.enum_types_by_name['Protocol']
Protocol = enum_type_wrapper.EnumTypeWrapper(_PROTOCOL)
_MOUNTPROPAGATION = DESCRIPTOR.enum_types_by_name['MountPropagation']
MountPropagation = enum_type_wrapper.EnumTypeWrapper(_MOUNTPROPAGATION)
_NAMESPACEMODE = DESCRIPTOR.enum_types_by_name['NamespaceMode']
NamespaceMode = enum_type_wrapper.EnumTypeWrapper(_NAMESPACEMODE)
_PODSANDBOXSTATE = DESCRIPTOR.enum_types_by_name['PodSandboxState']
PodSandboxState = enum_type_wrapper.EnumTypeWrapper(_PODSANDBOXSTATE)
_CONTAINERSTATE = DESCRIPTOR.enum_types_by_name['ContainerState']
ContainerState = enum_type_wrapper.EnumTypeWrapper(_CONTAINERSTATE)
TCP = 0
UDP = 1
SCTP = 2
PROPAGATION_PRIVATE = 0
PROPAGATION_HOST_TO_CONTAINER = 1
PROPAGATION_BIDIRECTIONAL = 2
POD = 0
CONTAINER = 1
NODE = 2
TARGET = 3
SANDBOX_READY = 0
SANDBOX_NOTREADY = 1
CONTAINER_CREATED = 0
CONTAINER_RUNNING = 1
CONTAINER_EXITED = 2
CONTAINER_UNKNOWN = 3


_VERSIONREQUEST = DESCRIPTOR.message_types_by_name['VersionRequest']
_VERSIONRESPONSE = DESCRIPTOR.message_types_by_name['VersionResponse']
_DNSCONFIG = DESCRIPTOR.message_types_by_name['DNSConfig']
_PORTMAPPING = DESCRIPTOR.message_types_by_name['PortMapping']
_MOUNT = DESCRIPTOR.message_types_by_name['Mount']
_IDMAPPING = DESCRIPTOR.message_types_by_name['IDMapping']
_USERNAMESPACE = DESCRIPTOR.message_types_by_name['UserNamespace']
_NAMESPACEOPTION = DESCRIPTOR.message_types_by_name['NamespaceOption']
_INT64VALUE = DESCRIPTOR.message_types_by_name['Int64Value']
_LINUXSANDBOXSECURITYCONTEXT = DESCRIPTOR.message_types_by_name['LinuxSandboxSecurityContext']
_SECURITYPROFILE = DESCRIPTOR.message_types_by_name['SecurityProfile']
_LINUXPODSANDBOXCONFIG = DESCRIPTOR.message_types_by_name['LinuxPodSandboxConfig']
_LINUXPODSANDBOXCONFIG_SYSCTLSENTRY = _LINUXPODSANDBOXCONFIG.nested_types_by_name['SysctlsEntry']
_PODSANDBOXMETADATA = DESCRIPTOR.message_types_by_name['PodSandboxMetadata']
_PODSANDBOXCONFIG = DESCRIPTOR.message_types_by_name['PodSandboxConfig']
_PODSANDBOXCONFIG_LABELSENTRY = _PODSANDBOXCONFIG.nested_types_by_name['LabelsEntry']
_PODSANDBOXCONFIG_ANNOTATIONSENTRY = _PODSANDBOXCONFIG.nested_types_by_name['AnnotationsEntry']
_RUNPODSANDBOXREQUEST = DESCRIPTOR.message_types_by_name['RunPodSandboxRequest']
_RUNPODSANDBOXRESPONSE = DESCRIPTOR.message_types_by_name['RunPodSandboxResponse']
_STOPPODSANDBOXREQUEST = DESCRIPTOR.message_types_by_name['StopPodSandboxRequest']
_STOPPODSANDBOXRESPONSE = DESCRIPTOR.message_types_by_name['StopPodSandboxResponse']
_REMOVEPODSANDBOXREQUEST = DESCRIPTOR.message_types_by_name['RemovePodSandboxRequest']
_REMOVEPODSANDBOXRESPONSE = DESCRIPTOR.message_types_by_name['RemovePodSandboxResponse']
_PODSANDBOXSTATUSREQUEST = DESCRIPTOR.message_types_by_name['PodSandboxStatusRequest']
_PODIP = DESCRIPTOR.message_types_by_name['PodIP']
_PODSANDBOXNETWORKSTATUS = DESCRIPTOR.message_types_by_name['PodSandboxNetworkStatus']
_NAMESPACE = DESCRIPTOR.message_types_by_name['Namespace']
_LINUXPODSANDBOXSTATUS = DESCRIPTOR.message_types_by_name['LinuxPodSandboxStatus']
_PODSANDBOXSTATUS = DESCRIPTOR.message_types_by_name['PodSandboxStatus']
_PODSANDBOXSTATUS_LABELSENTRY = _PODSANDBOXSTATUS.nested_types_by_name['LabelsEntry']
_PODSANDBOXSTATUS_ANNOTATIONSENTRY = _PODSANDBOXSTATUS.nested_types_by_name['AnnotationsEntry']
_PODSANDBOXSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['PodSandboxStatusResponse']
_PODSANDBOXSTATUSRESPONSE_INFOENTRY = _PODSANDBOXSTATUSRESPONSE.nested_types_by_name['InfoEntry']
_PODSANDBOXSTATEVALUE = DESCRIPTOR.message_types_by_name['PodSandboxStateValue']
_PODSANDBOXFILTER = DESCRIPTOR.message_types_by_name['PodSandboxFilter']
_PODSANDBOXFILTER_LABELSELECTORENTRY = _PODSANDBOXFILTER.nested_types_by_name['LabelSelectorEntry']
_LISTPODSANDBOXREQUEST = DESCRIPTOR.message_types_by_name['ListPodSandboxRequest']
_PODSANDBOX = DESCRIPTOR.message_types_by_name['PodSandbox']
_PODSANDBOX_LABELSENTRY = _PODSANDBOX.nested_types_by_name['LabelsEntry']
_PODSANDBOX_ANNOTATIONSENTRY = _PODSANDBOX.nested_types_by_name['AnnotationsEntry']
_LISTPODSANDBOXRESPONSE = DESCRIPTOR.message_types_by_name['ListPodSandboxResponse']
_PODSANDBOXSTATSREQUEST = DESCRIPTOR.message_types_by_name['PodSandboxStatsRequest']
_PODSANDBOXSTATSRESPONSE = DESCRIPTOR.message_types_by_name['PodSandboxStatsResponse']
_PODSANDBOXSTATSFILTER = DESCRIPTOR.message_types_by_name['PodSandboxStatsFilter']
_PODSANDBOXSTATSFILTER_LABELSELECTORENTRY = _PODSANDBOXSTATSFILTER.nested_types_by_name['LabelSelectorEntry']
_LISTPODSANDBOXSTATSREQUEST = DESCRIPTOR.message_types_by_name['ListPodSandboxStatsRequest']
_LISTPODSANDBOXSTATSRESPONSE = DESCRIPTOR.message_types_by_name['ListPodSandboxStatsResponse']
_PODSANDBOXATTRIBUTES = DESCRIPTOR.message_types_by_name['PodSandboxAttributes']
_PODSANDBOXATTRIBUTES_LABELSENTRY = _PODSANDBOXATTRIBUTES.nested_types_by_name['LabelsEntry']
_PODSANDBOXATTRIBUTES_ANNOTATIONSENTRY = _PODSANDBOXATTRIBUTES.nested_types_by_name['AnnotationsEntry']
_PODSANDBOXSTATS = DESCRIPTOR.message_types_by_name['PodSandboxStats']
_LINUXPODSANDBOXSTATS = DESCRIPTOR.message_types_by_name['LinuxPodSandboxStats']
_WINDOWSPODSANDBOXSTATS = DESCRIPTOR.message_types_by_name['WindowsPodSandboxStats']
_NETWORKUSAGE = DESCRIPTOR.message_types_by_name['NetworkUsage']
_NETWORKINTERFACEUSAGE = DESCRIPTOR.message_types_by_name['NetworkInterfaceUsage']
_PROCESSUSAGE = DESCRIPTOR.message_types_by_name['ProcessUsage']
_IMAGESPEC = DESCRIPTOR.message_types_by_name['ImageSpec']
_IMAGESPEC_ANNOTATIONSENTRY = _IMAGESPEC.nested_types_by_name['AnnotationsEntry']
_KEYVALUE = DESCRIPTOR.message_types_by_name['KeyValue']
_LINUXCONTAINERRESOURCES = DESCRIPTOR.message_types_by_name['LinuxContainerResources']
_LINUXCONTAINERRESOURCES_UNIFIEDENTRY = _LINUXCONTAINERRESOURCES.nested_types_by_name['UnifiedEntry']
_HUGEPAGELIMIT = DESCRIPTOR.message_types_by_name['HugepageLimit']
_SELINUXOPTION = DESCRIPTOR.message_types_by_name['SELinuxOption']
_CAPABILITY = DESCRIPTOR.message_types_by_name['Capability']
_LINUXCONTAINERSECURITYCONTEXT = DESCRIPTOR.message_types_by_name['LinuxContainerSecurityContext']
_LINUXCONTAINERCONFIG = DESCRIPTOR.message_types_by_name['LinuxContainerConfig']
_WINDOWSSANDBOXSECURITYCONTEXT = DESCRIPTOR.message_types_by_name['WindowsSandboxSecurityContext']
_WINDOWSPODSANDBOXCONFIG = DESCRIPTOR.message_types_by_name['WindowsPodSandboxConfig']
_WINDOWSCONTAINERSECURITYCONTEXT = DESCRIPTOR.message_types_by_name['WindowsContainerSecurityContext']
_WINDOWSCONTAINERCONFIG = DESCRIPTOR.message_types_by_name['WindowsContainerConfig']
_WINDOWSCONTAINERRESOURCES = DESCRIPTOR.message_types_by_name['WindowsContainerResources']
_CONTAINERMETADATA = DESCRIPTOR.message_types_by_name['ContainerMetadata']
_DEVICE = DESCRIPTOR.message_types_by_name['Device']
_CONTAINERCONFIG = DESCRIPTOR.message_types_by_name['ContainerConfig']
_CONTAINERCONFIG_LABELSENTRY = _CONTAINERCONFIG.nested_types_by_name['LabelsEntry']
_CONTAINERCONFIG_ANNOTATIONSENTRY = _CONTAINERCONFIG.nested_types_by_name['AnnotationsEntry']
_CREATECONTAINERREQUEST = DESCRIPTOR.message_types_by_name['CreateContainerRequest']
_CREATECONTAINERRESPONSE = DESCRIPTOR.message_types_by_name['CreateContainerResponse']
_STARTCONTAINERREQUEST = DESCRIPTOR.message_types_by_name['StartContainerRequest']
_STARTCONTAINERRESPONSE = DESCRIPTOR.message_types_by_name['StartContainerResponse']
_STOPCONTAINERREQUEST = DESCRIPTOR.message_types_by_name['StopContainerRequest']
_STOPCONTAINERRESPONSE = DESCRIPTOR.message_types_by_name['StopContainerResponse']
_REMOVECONTAINERREQUEST = DESCRIPTOR.message_types_by_name['RemoveContainerRequest']
_REMOVECONTAINERRESPONSE = DESCRIPTOR.message_types_by_name['RemoveContainerResponse']
_CONTAINERSTATEVALUE = DESCRIPTOR.message_types_by_name['ContainerStateValue']
_CONTAINERFILTER = DESCRIPTOR.message_types_by_name['ContainerFilter']
_CONTAINERFILTER_LABELSELECTORENTRY = _CONTAINERFILTER.nested_types_by_name['LabelSelectorEntry']
_LISTCONTAINERSREQUEST = DESCRIPTOR.message_types_by_name['ListContainersRequest']
_CONTAINER = DESCRIPTOR.message_types_by_name['Container']
_CONTAINER_LABELSENTRY = _CONTAINER.nested_types_by_name['LabelsEntry']
_CONTAINER_ANNOTATIONSENTRY = _CONTAINER.nested_types_by_name['AnnotationsEntry']
_LISTCONTAINERSRESPONSE = DESCRIPTOR.message_types_by_name['ListContainersResponse']
_CONTAINERSTATUSREQUEST = DESCRIPTOR.message_types_by_name['ContainerStatusRequest']
_CONTAINERSTATUS = DESCRIPTOR.message_types_by_name['ContainerStatus']
_CONTAINERSTATUS_LABELSENTRY = _CONTAINERSTATUS.nested_types_by_name['LabelsEntry']
_CONTAINERSTATUS_ANNOTATIONSENTRY = _CONTAINERSTATUS.nested_types_by_name['AnnotationsEntry']
_CONTAINERSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['ContainerStatusResponse']
_CONTAINERSTATUSRESPONSE_INFOENTRY = _CONTAINERSTATUSRESPONSE.nested_types_by_name['InfoEntry']
_UPDATECONTAINERRESOURCESREQUEST = DESCRIPTOR.message_types_by_name['UpdateContainerResourcesRequest']
_UPDATECONTAINERRESOURCESREQUEST_ANNOTATIONSENTRY = _UPDATECONTAINERRESOURCESREQUEST.nested_types_by_name['AnnotationsEntry']
_UPDATECONTAINERRESOURCESRESPONSE = DESCRIPTOR.message_types_by_name['UpdateContainerResourcesResponse']
_EXECSYNCREQUEST = DESCRIPTOR.message_types_by_name['ExecSyncRequest']
_EXECSYNCRESPONSE = DESCRIPTOR.message_types_by_name['ExecSyncResponse']
_EXECREQUEST = DESCRIPTOR.message_types_by_name['ExecRequest']
_EXECRESPONSE = DESCRIPTOR.message_types_by_name['ExecResponse']
_ATTACHREQUEST = DESCRIPTOR.message_types_by_name['AttachRequest']
_ATTACHRESPONSE = DESCRIPTOR.message_types_by_name['AttachResponse']
_PORTFORWARDREQUEST = DESCRIPTOR.message_types_by_name['PortForwardRequest']
_PORTFORWARDRESPONSE = DESCRIPTOR.message_types_by_name['PortForwardResponse']
_IMAGEFILTER = DESCRIPTOR.message_types_by_name['ImageFilter']
_LISTIMAGESREQUEST = DESCRIPTOR.message_types_by_name['ListImagesRequest']
_IMAGE = DESCRIPTOR.message_types_by_name['Image']
_LISTIMAGESRESPONSE = DESCRIPTOR.message_types_by_name['ListImagesResponse']
_IMAGESTATUSREQUEST = DESCRIPTOR.message_types_by_name['ImageStatusRequest']
_IMAGESTATUSRESPONSE = DESCRIPTOR.message_types_by_name['ImageStatusResponse']
_IMAGESTATUSRESPONSE_INFOENTRY = _IMAGESTATUSRESPONSE.nested_types_by_name['InfoEntry']
_AUTHCONFIG = DESCRIPTOR.message_types_by_name['AuthConfig']
_PULLIMAGEREQUEST = DESCRIPTOR.message_types_by_name['PullImageRequest']
_PULLIMAGERESPONSE = DESCRIPTOR.message_types_by_name['PullImageResponse']
_REMOVEIMAGEREQUEST = DESCRIPTOR.message_types_by_name['RemoveImageRequest']
_REMOVEIMAGERESPONSE = DESCRIPTOR.message_types_by_name['RemoveImageResponse']
_NETWORKCONFIG = DESCRIPTOR.message_types_by_name['NetworkConfig']
_RUNTIMECONFIG = DESCRIPTOR.message_types_by_name['RuntimeConfig']
_UPDATERUNTIMECONFIGREQUEST = DESCRIPTOR.message_types_by_name['UpdateRuntimeConfigRequest']
_UPDATERUNTIMECONFIGRESPONSE = DESCRIPTOR.message_types_by_name['UpdateRuntimeConfigResponse']
_RUNTIMECONDITION = DESCRIPTOR.message_types_by_name['RuntimeCondition']
_RUNTIMESTATUS = DESCRIPTOR.message_types_by_name['RuntimeStatus']
_STATUSREQUEST = DESCRIPTOR.message_types_by_name['StatusRequest']
_STATUSRESPONSE = DESCRIPTOR.message_types_by_name['StatusResponse']
_STATUSRESPONSE_INFOENTRY = _STATUSRESPONSE.nested_types_by_name['InfoEntry']
_IMAGEFSINFOREQUEST = DESCRIPTOR.message_types_by_name['ImageFsInfoRequest']
_UINT64VALUE = DESCRIPTOR.message_types_by_name['UInt64Value']
_FILESYSTEMIDENTIFIER = DESCRIPTOR.message_types_by_name['FilesystemIdentifier']
_FILESYSTEMUSAGE = DESCRIPTOR.message_types_by_name['FilesystemUsage']
_IMAGEFSINFORESPONSE = DESCRIPTOR.message_types_by_name['ImageFsInfoResponse']
_CONTAINERSTATSREQUEST = DESCRIPTOR.message_types_by_name['ContainerStatsRequest']
_CONTAINERSTATSRESPONSE = DESCRIPTOR.message_types_by_name['ContainerStatsResponse']
_LISTCONTAINERSTATSREQUEST = DESCRIPTOR.message_types_by_name['ListContainerStatsRequest']
_CONTAINERSTATSFILTER = DESCRIPTOR.message_types_by_name['ContainerStatsFilter']
_CONTAINERSTATSFILTER_LABELSELECTORENTRY = _CONTAINERSTATSFILTER.nested_types_by_name['LabelSelectorEntry']
_LISTCONTAINERSTATSRESPONSE = DESCRIPTOR.message_types_by_name['ListContainerStatsResponse']
_CONTAINERATTRIBUTES = DESCRIPTOR.message_types_by_name['ContainerAttributes']
_CONTAINERATTRIBUTES_LABELSENTRY = _CONTAINERATTRIBUTES.nested_types_by_name['LabelsEntry']
_CONTAINERATTRIBUTES_ANNOTATIONSENTRY = _CONTAINERATTRIBUTES.nested_types_by_name['AnnotationsEntry']
_CONTAINERSTATS = DESCRIPTOR.message_types_by_name['ContainerStats']
_CPUUSAGE = DESCRIPTOR.message_types_by_name['CpuUsage']
_MEMORYUSAGE = DESCRIPTOR.message_types_by_name['MemoryUsage']
_REOPENCONTAINERLOGREQUEST = DESCRIPTOR.message_types_by_name['ReopenContainerLogRequest']
_REOPENCONTAINERLOGRESPONSE = DESCRIPTOR.message_types_by_name['ReopenContainerLogResponse']
_SECURITYPROFILE_PROFILETYPE = _SECURITYPROFILE.enum_types_by_name['ProfileType']
VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.VersionRequest)
  })
_sym_db.RegisterMessage(VersionRequest)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.VersionResponse)
  })
_sym_db.RegisterMessage(VersionResponse)

DNSConfig = _reflection.GeneratedProtocolMessageType('DNSConfig', (_message.Message,), {
  'DESCRIPTOR' : _DNSCONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.DNSConfig)
  })
_sym_db.RegisterMessage(DNSConfig)

PortMapping = _reflection.GeneratedProtocolMessageType('PortMapping', (_message.Message,), {
  'DESCRIPTOR' : _PORTMAPPING,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PortMapping)
  })
_sym_db.RegisterMessage(PortMapping)

Mount = _reflection.GeneratedProtocolMessageType('Mount', (_message.Message,), {
  'DESCRIPTOR' : _MOUNT,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.Mount)
  })
_sym_db.RegisterMessage(Mount)

IDMapping = _reflection.GeneratedProtocolMessageType('IDMapping', (_message.Message,), {
  'DESCRIPTOR' : _IDMAPPING,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.IDMapping)
  })
_sym_db.RegisterMessage(IDMapping)

UserNamespace = _reflection.GeneratedProtocolMessageType('UserNamespace', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMESPACE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.UserNamespace)
  })
_sym_db.RegisterMessage(UserNamespace)

NamespaceOption = _reflection.GeneratedProtocolMessageType('NamespaceOption', (_message.Message,), {
  'DESCRIPTOR' : _NAMESPACEOPTION,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.NamespaceOption)
  })
_sym_db.RegisterMessage(NamespaceOption)

Int64Value = _reflection.GeneratedProtocolMessageType('Int64Value', (_message.Message,), {
  'DESCRIPTOR' : _INT64VALUE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.Int64Value)
  })
_sym_db.RegisterMessage(Int64Value)

LinuxSandboxSecurityContext = _reflection.GeneratedProtocolMessageType('LinuxSandboxSecurityContext', (_message.Message,), {
  'DESCRIPTOR' : _LINUXSANDBOXSECURITYCONTEXT,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.LinuxSandboxSecurityContext)
  })
_sym_db.RegisterMessage(LinuxSandboxSecurityContext)

SecurityProfile = _reflection.GeneratedProtocolMessageType('SecurityProfile', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYPROFILE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.SecurityProfile)
  })
_sym_db.RegisterMessage(SecurityProfile)

LinuxPodSandboxConfig = _reflection.GeneratedProtocolMessageType('LinuxPodSandboxConfig', (_message.Message,), {

  'SysctlsEntry' : _reflection.GeneratedProtocolMessageType('SysctlsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LINUXPODSANDBOXCONFIG_SYSCTLSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.LinuxPodSandboxConfig.SysctlsEntry)
    })
  ,
  'DESCRIPTOR' : _LINUXPODSANDBOXCONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.LinuxPodSandboxConfig)
  })
_sym_db.RegisterMessage(LinuxPodSandboxConfig)
_sym_db.RegisterMessage(LinuxPodSandboxConfig.SysctlsEntry)

PodSandboxMetadata = _reflection.GeneratedProtocolMessageType('PodSandboxMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PODSANDBOXMETADATA,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxMetadata)
  })
_sym_db.RegisterMessage(PodSandboxMetadata)

PodSandboxConfig = _reflection.GeneratedProtocolMessageType('PodSandboxConfig', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOXCONFIG_LABELSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxConfig.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOXCONFIG_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxConfig.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _PODSANDBOXCONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxConfig)
  })
_sym_db.RegisterMessage(PodSandboxConfig)
_sym_db.RegisterMessage(PodSandboxConfig.LabelsEntry)
_sym_db.RegisterMessage(PodSandboxConfig.AnnotationsEntry)

RunPodSandboxRequest = _reflection.GeneratedProtocolMessageType('RunPodSandboxRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNPODSANDBOXREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RunPodSandboxRequest)
  })
_sym_db.RegisterMessage(RunPodSandboxRequest)

RunPodSandboxResponse = _reflection.GeneratedProtocolMessageType('RunPodSandboxResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNPODSANDBOXRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RunPodSandboxResponse)
  })
_sym_db.RegisterMessage(RunPodSandboxResponse)

StopPodSandboxRequest = _reflection.GeneratedProtocolMessageType('StopPodSandboxRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPPODSANDBOXREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.StopPodSandboxRequest)
  })
_sym_db.RegisterMessage(StopPodSandboxRequest)

StopPodSandboxResponse = _reflection.GeneratedProtocolMessageType('StopPodSandboxResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPPODSANDBOXRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.StopPodSandboxResponse)
  })
_sym_db.RegisterMessage(StopPodSandboxResponse)

RemovePodSandboxRequest = _reflection.GeneratedProtocolMessageType('RemovePodSandboxRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPODSANDBOXREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RemovePodSandboxRequest)
  })
_sym_db.RegisterMessage(RemovePodSandboxRequest)

RemovePodSandboxResponse = _reflection.GeneratedProtocolMessageType('RemovePodSandboxResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPODSANDBOXRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RemovePodSandboxResponse)
  })
_sym_db.RegisterMessage(RemovePodSandboxResponse)

PodSandboxStatusRequest = _reflection.GeneratedProtocolMessageType('PodSandboxStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _PODSANDBOXSTATUSREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatusRequest)
  })
_sym_db.RegisterMessage(PodSandboxStatusRequest)

PodIP = _reflection.GeneratedProtocolMessageType('PodIP', (_message.Message,), {
  'DESCRIPTOR' : _PODIP,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodIP)
  })
_sym_db.RegisterMessage(PodIP)

PodSandboxNetworkStatus = _reflection.GeneratedProtocolMessageType('PodSandboxNetworkStatus', (_message.Message,), {
  'DESCRIPTOR' : _PODSANDBOXNETWORKSTATUS,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxNetworkStatus)
  })
_sym_db.RegisterMessage(PodSandboxNetworkStatus)

Namespace = _reflection.GeneratedProtocolMessageType('Namespace', (_message.Message,), {
  'DESCRIPTOR' : _NAMESPACE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.Namespace)
  })
_sym_db.RegisterMessage(Namespace)

LinuxPodSandboxStatus = _reflection.GeneratedProtocolMessageType('LinuxPodSandboxStatus', (_message.Message,), {
  'DESCRIPTOR' : _LINUXPODSANDBOXSTATUS,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.LinuxPodSandboxStatus)
  })
_sym_db.RegisterMessage(LinuxPodSandboxStatus)

PodSandboxStatus = _reflection.GeneratedProtocolMessageType('PodSandboxStatus', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOXSTATUS_LABELSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatus.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOXSTATUS_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatus.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _PODSANDBOXSTATUS,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatus)
  })
_sym_db.RegisterMessage(PodSandboxStatus)
_sym_db.RegisterMessage(PodSandboxStatus.LabelsEntry)
_sym_db.RegisterMessage(PodSandboxStatus.AnnotationsEntry)

PodSandboxStatusResponse = _reflection.GeneratedProtocolMessageType('PodSandboxStatusResponse', (_message.Message,), {

  'InfoEntry' : _reflection.GeneratedProtocolMessageType('InfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOXSTATUSRESPONSE_INFOENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatusResponse.InfoEntry)
    })
  ,
  'DESCRIPTOR' : _PODSANDBOXSTATUSRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatusResponse)
  })
_sym_db.RegisterMessage(PodSandboxStatusResponse)
_sym_db.RegisterMessage(PodSandboxStatusResponse.InfoEntry)

PodSandboxStateValue = _reflection.GeneratedProtocolMessageType('PodSandboxStateValue', (_message.Message,), {
  'DESCRIPTOR' : _PODSANDBOXSTATEVALUE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStateValue)
  })
_sym_db.RegisterMessage(PodSandboxStateValue)

PodSandboxFilter = _reflection.GeneratedProtocolMessageType('PodSandboxFilter', (_message.Message,), {

  'LabelSelectorEntry' : _reflection.GeneratedProtocolMessageType('LabelSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOXFILTER_LABELSELECTORENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxFilter.LabelSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _PODSANDBOXFILTER,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxFilter)
  })
_sym_db.RegisterMessage(PodSandboxFilter)
_sym_db.RegisterMessage(PodSandboxFilter.LabelSelectorEntry)

ListPodSandboxRequest = _reflection.GeneratedProtocolMessageType('ListPodSandboxRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPODSANDBOXREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListPodSandboxRequest)
  })
_sym_db.RegisterMessage(ListPodSandboxRequest)

PodSandbox = _reflection.GeneratedProtocolMessageType('PodSandbox', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOX_LABELSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandbox.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOX_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandbox.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _PODSANDBOX,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandbox)
  })
_sym_db.RegisterMessage(PodSandbox)
_sym_db.RegisterMessage(PodSandbox.LabelsEntry)
_sym_db.RegisterMessage(PodSandbox.AnnotationsEntry)

ListPodSandboxResponse = _reflection.GeneratedProtocolMessageType('ListPodSandboxResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPODSANDBOXRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListPodSandboxResponse)
  })
_sym_db.RegisterMessage(ListPodSandboxResponse)

PodSandboxStatsRequest = _reflection.GeneratedProtocolMessageType('PodSandboxStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PODSANDBOXSTATSREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatsRequest)
  })
_sym_db.RegisterMessage(PodSandboxStatsRequest)

PodSandboxStatsResponse = _reflection.GeneratedProtocolMessageType('PodSandboxStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _PODSANDBOXSTATSRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatsResponse)
  })
_sym_db.RegisterMessage(PodSandboxStatsResponse)

PodSandboxStatsFilter = _reflection.GeneratedProtocolMessageType('PodSandboxStatsFilter', (_message.Message,), {

  'LabelSelectorEntry' : _reflection.GeneratedProtocolMessageType('LabelSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOXSTATSFILTER_LABELSELECTORENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatsFilter.LabelSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _PODSANDBOXSTATSFILTER,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStatsFilter)
  })
_sym_db.RegisterMessage(PodSandboxStatsFilter)
_sym_db.RegisterMessage(PodSandboxStatsFilter.LabelSelectorEntry)

ListPodSandboxStatsRequest = _reflection.GeneratedProtocolMessageType('ListPodSandboxStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPODSANDBOXSTATSREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListPodSandboxStatsRequest)
  })
_sym_db.RegisterMessage(ListPodSandboxStatsRequest)

ListPodSandboxStatsResponse = _reflection.GeneratedProtocolMessageType('ListPodSandboxStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPODSANDBOXSTATSRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListPodSandboxStatsResponse)
  })
_sym_db.RegisterMessage(ListPodSandboxStatsResponse)

PodSandboxAttributes = _reflection.GeneratedProtocolMessageType('PodSandboxAttributes', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOXATTRIBUTES_LABELSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxAttributes.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSANDBOXATTRIBUTES_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxAttributes.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _PODSANDBOXATTRIBUTES,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxAttributes)
  })
_sym_db.RegisterMessage(PodSandboxAttributes)
_sym_db.RegisterMessage(PodSandboxAttributes.LabelsEntry)
_sym_db.RegisterMessage(PodSandboxAttributes.AnnotationsEntry)

PodSandboxStats = _reflection.GeneratedProtocolMessageType('PodSandboxStats', (_message.Message,), {
  'DESCRIPTOR' : _PODSANDBOXSTATS,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PodSandboxStats)
  })
_sym_db.RegisterMessage(PodSandboxStats)

LinuxPodSandboxStats = _reflection.GeneratedProtocolMessageType('LinuxPodSandboxStats', (_message.Message,), {
  'DESCRIPTOR' : _LINUXPODSANDBOXSTATS,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.LinuxPodSandboxStats)
  })
_sym_db.RegisterMessage(LinuxPodSandboxStats)

WindowsPodSandboxStats = _reflection.GeneratedProtocolMessageType('WindowsPodSandboxStats', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWSPODSANDBOXSTATS,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.WindowsPodSandboxStats)
  })
_sym_db.RegisterMessage(WindowsPodSandboxStats)

NetworkUsage = _reflection.GeneratedProtocolMessageType('NetworkUsage', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKUSAGE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.NetworkUsage)
  })
_sym_db.RegisterMessage(NetworkUsage)

NetworkInterfaceUsage = _reflection.GeneratedProtocolMessageType('NetworkInterfaceUsage', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKINTERFACEUSAGE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.NetworkInterfaceUsage)
  })
_sym_db.RegisterMessage(NetworkInterfaceUsage)

ProcessUsage = _reflection.GeneratedProtocolMessageType('ProcessUsage', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSUSAGE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ProcessUsage)
  })
_sym_db.RegisterMessage(ProcessUsage)

ImageSpec = _reflection.GeneratedProtocolMessageType('ImageSpec', (_message.Message,), {

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _IMAGESPEC_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ImageSpec.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _IMAGESPEC,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ImageSpec)
  })
_sym_db.RegisterMessage(ImageSpec)
_sym_db.RegisterMessage(ImageSpec.AnnotationsEntry)

KeyValue = _reflection.GeneratedProtocolMessageType('KeyValue', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.KeyValue)
  })
_sym_db.RegisterMessage(KeyValue)

LinuxContainerResources = _reflection.GeneratedProtocolMessageType('LinuxContainerResources', (_message.Message,), {

  'UnifiedEntry' : _reflection.GeneratedProtocolMessageType('UnifiedEntry', (_message.Message,), {
    'DESCRIPTOR' : _LINUXCONTAINERRESOURCES_UNIFIEDENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.LinuxContainerResources.UnifiedEntry)
    })
  ,
  'DESCRIPTOR' : _LINUXCONTAINERRESOURCES,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.LinuxContainerResources)
  })
_sym_db.RegisterMessage(LinuxContainerResources)
_sym_db.RegisterMessage(LinuxContainerResources.UnifiedEntry)

HugepageLimit = _reflection.GeneratedProtocolMessageType('HugepageLimit', (_message.Message,), {
  'DESCRIPTOR' : _HUGEPAGELIMIT,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.HugepageLimit)
  })
_sym_db.RegisterMessage(HugepageLimit)

SELinuxOption = _reflection.GeneratedProtocolMessageType('SELinuxOption', (_message.Message,), {
  'DESCRIPTOR' : _SELINUXOPTION,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.SELinuxOption)
  })
_sym_db.RegisterMessage(SELinuxOption)

Capability = _reflection.GeneratedProtocolMessageType('Capability', (_message.Message,), {
  'DESCRIPTOR' : _CAPABILITY,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.Capability)
  })
_sym_db.RegisterMessage(Capability)

LinuxContainerSecurityContext = _reflection.GeneratedProtocolMessageType('LinuxContainerSecurityContext', (_message.Message,), {
  'DESCRIPTOR' : _LINUXCONTAINERSECURITYCONTEXT,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.LinuxContainerSecurityContext)
  })
_sym_db.RegisterMessage(LinuxContainerSecurityContext)

LinuxContainerConfig = _reflection.GeneratedProtocolMessageType('LinuxContainerConfig', (_message.Message,), {
  'DESCRIPTOR' : _LINUXCONTAINERCONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.LinuxContainerConfig)
  })
_sym_db.RegisterMessage(LinuxContainerConfig)

WindowsSandboxSecurityContext = _reflection.GeneratedProtocolMessageType('WindowsSandboxSecurityContext', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWSSANDBOXSECURITYCONTEXT,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.WindowsSandboxSecurityContext)
  })
_sym_db.RegisterMessage(WindowsSandboxSecurityContext)

WindowsPodSandboxConfig = _reflection.GeneratedProtocolMessageType('WindowsPodSandboxConfig', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWSPODSANDBOXCONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.WindowsPodSandboxConfig)
  })
_sym_db.RegisterMessage(WindowsPodSandboxConfig)

WindowsContainerSecurityContext = _reflection.GeneratedProtocolMessageType('WindowsContainerSecurityContext', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWSCONTAINERSECURITYCONTEXT,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.WindowsContainerSecurityContext)
  })
_sym_db.RegisterMessage(WindowsContainerSecurityContext)

WindowsContainerConfig = _reflection.GeneratedProtocolMessageType('WindowsContainerConfig', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWSCONTAINERCONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.WindowsContainerConfig)
  })
_sym_db.RegisterMessage(WindowsContainerConfig)

WindowsContainerResources = _reflection.GeneratedProtocolMessageType('WindowsContainerResources', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWSCONTAINERRESOURCES,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.WindowsContainerResources)
  })
_sym_db.RegisterMessage(WindowsContainerResources)

ContainerMetadata = _reflection.GeneratedProtocolMessageType('ContainerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERMETADATA,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerMetadata)
  })
_sym_db.RegisterMessage(ContainerMetadata)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.Device)
  })
_sym_db.RegisterMessage(Device)

ContainerConfig = _reflection.GeneratedProtocolMessageType('ContainerConfig', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERCONFIG_LABELSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerConfig.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERCONFIG_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerConfig.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINERCONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerConfig)
  })
_sym_db.RegisterMessage(ContainerConfig)
_sym_db.RegisterMessage(ContainerConfig.LabelsEntry)
_sym_db.RegisterMessage(ContainerConfig.AnnotationsEntry)

CreateContainerRequest = _reflection.GeneratedProtocolMessageType('CreateContainerRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONTAINERREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.CreateContainerRequest)
  })
_sym_db.RegisterMessage(CreateContainerRequest)

CreateContainerResponse = _reflection.GeneratedProtocolMessageType('CreateContainerResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONTAINERRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.CreateContainerResponse)
  })
_sym_db.RegisterMessage(CreateContainerResponse)

StartContainerRequest = _reflection.GeneratedProtocolMessageType('StartContainerRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTCONTAINERREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.StartContainerRequest)
  })
_sym_db.RegisterMessage(StartContainerRequest)

StartContainerResponse = _reflection.GeneratedProtocolMessageType('StartContainerResponse', (_message.Message,), {
  'DESCRIPTOR' : _STARTCONTAINERRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.StartContainerResponse)
  })
_sym_db.RegisterMessage(StartContainerResponse)

StopContainerRequest = _reflection.GeneratedProtocolMessageType('StopContainerRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPCONTAINERREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.StopContainerRequest)
  })
_sym_db.RegisterMessage(StopContainerRequest)

StopContainerResponse = _reflection.GeneratedProtocolMessageType('StopContainerResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPCONTAINERRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.StopContainerResponse)
  })
_sym_db.RegisterMessage(StopContainerResponse)

RemoveContainerRequest = _reflection.GeneratedProtocolMessageType('RemoveContainerRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVECONTAINERREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RemoveContainerRequest)
  })
_sym_db.RegisterMessage(RemoveContainerRequest)

RemoveContainerResponse = _reflection.GeneratedProtocolMessageType('RemoveContainerResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVECONTAINERRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RemoveContainerResponse)
  })
_sym_db.RegisterMessage(RemoveContainerResponse)

ContainerStateValue = _reflection.GeneratedProtocolMessageType('ContainerStateValue', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATEVALUE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStateValue)
  })
_sym_db.RegisterMessage(ContainerStateValue)

ContainerFilter = _reflection.GeneratedProtocolMessageType('ContainerFilter', (_message.Message,), {

  'LabelSelectorEntry' : _reflection.GeneratedProtocolMessageType('LabelSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERFILTER_LABELSELECTORENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerFilter.LabelSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINERFILTER,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerFilter)
  })
_sym_db.RegisterMessage(ContainerFilter)
_sym_db.RegisterMessage(ContainerFilter.LabelSelectorEntry)

ListContainersRequest = _reflection.GeneratedProtocolMessageType('ListContainersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListContainersRequest)
  })
_sym_db.RegisterMessage(ListContainersRequest)

Container = _reflection.GeneratedProtocolMessageType('Container', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINER_LABELSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.Container.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINER_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.Container.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINER,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.Container)
  })
_sym_db.RegisterMessage(Container)
_sym_db.RegisterMessage(Container.LabelsEntry)
_sym_db.RegisterMessage(Container.AnnotationsEntry)

ListContainersResponse = _reflection.GeneratedProtocolMessageType('ListContainersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListContainersResponse)
  })
_sym_db.RegisterMessage(ListContainersResponse)

ContainerStatusRequest = _reflection.GeneratedProtocolMessageType('ContainerStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATUSREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatusRequest)
  })
_sym_db.RegisterMessage(ContainerStatusRequest)

ContainerStatus = _reflection.GeneratedProtocolMessageType('ContainerStatus', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERSTATUS_LABELSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatus.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERSTATUS_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatus.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINERSTATUS,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatus)
  })
_sym_db.RegisterMessage(ContainerStatus)
_sym_db.RegisterMessage(ContainerStatus.LabelsEntry)
_sym_db.RegisterMessage(ContainerStatus.AnnotationsEntry)

ContainerStatusResponse = _reflection.GeneratedProtocolMessageType('ContainerStatusResponse', (_message.Message,), {

  'InfoEntry' : _reflection.GeneratedProtocolMessageType('InfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERSTATUSRESPONSE_INFOENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatusResponse.InfoEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINERSTATUSRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatusResponse)
  })
_sym_db.RegisterMessage(ContainerStatusResponse)
_sym_db.RegisterMessage(ContainerStatusResponse.InfoEntry)

UpdateContainerResourcesRequest = _reflection.GeneratedProtocolMessageType('UpdateContainerResourcesRequest', (_message.Message,), {

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECONTAINERRESOURCESREQUEST_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.UpdateContainerResourcesRequest.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECONTAINERRESOURCESREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.UpdateContainerResourcesRequest)
  })
_sym_db.RegisterMessage(UpdateContainerResourcesRequest)
_sym_db.RegisterMessage(UpdateContainerResourcesRequest.AnnotationsEntry)

UpdateContainerResourcesResponse = _reflection.GeneratedProtocolMessageType('UpdateContainerResourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONTAINERRESOURCESRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.UpdateContainerResourcesResponse)
  })
_sym_db.RegisterMessage(UpdateContainerResourcesResponse)

ExecSyncRequest = _reflection.GeneratedProtocolMessageType('ExecSyncRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECSYNCREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ExecSyncRequest)
  })
_sym_db.RegisterMessage(ExecSyncRequest)

ExecSyncResponse = _reflection.GeneratedProtocolMessageType('ExecSyncResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECSYNCRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ExecSyncResponse)
  })
_sym_db.RegisterMessage(ExecSyncResponse)

ExecRequest = _reflection.GeneratedProtocolMessageType('ExecRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ExecRequest)
  })
_sym_db.RegisterMessage(ExecRequest)

ExecResponse = _reflection.GeneratedProtocolMessageType('ExecResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ExecResponse)
  })
_sym_db.RegisterMessage(ExecResponse)

AttachRequest = _reflection.GeneratedProtocolMessageType('AttachRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.AttachRequest)
  })
_sym_db.RegisterMessage(AttachRequest)

AttachResponse = _reflection.GeneratedProtocolMessageType('AttachResponse', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.AttachResponse)
  })
_sym_db.RegisterMessage(AttachResponse)

PortForwardRequest = _reflection.GeneratedProtocolMessageType('PortForwardRequest', (_message.Message,), {
  'DESCRIPTOR' : _PORTFORWARDREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PortForwardRequest)
  })
_sym_db.RegisterMessage(PortForwardRequest)

PortForwardResponse = _reflection.GeneratedProtocolMessageType('PortForwardResponse', (_message.Message,), {
  'DESCRIPTOR' : _PORTFORWARDRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PortForwardResponse)
  })
_sym_db.RegisterMessage(PortForwardResponse)

ImageFilter = _reflection.GeneratedProtocolMessageType('ImageFilter', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEFILTER,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ImageFilter)
  })
_sym_db.RegisterMessage(ImageFilter)

ListImagesRequest = _reflection.GeneratedProtocolMessageType('ListImagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTIMAGESREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListImagesRequest)
  })
_sym_db.RegisterMessage(ListImagesRequest)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.Image)
  })
_sym_db.RegisterMessage(Image)

ListImagesResponse = _reflection.GeneratedProtocolMessageType('ListImagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTIMAGESRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListImagesResponse)
  })
_sym_db.RegisterMessage(ListImagesResponse)

ImageStatusRequest = _reflection.GeneratedProtocolMessageType('ImageStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMAGESTATUSREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ImageStatusRequest)
  })
_sym_db.RegisterMessage(ImageStatusRequest)

ImageStatusResponse = _reflection.GeneratedProtocolMessageType('ImageStatusResponse', (_message.Message,), {

  'InfoEntry' : _reflection.GeneratedProtocolMessageType('InfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _IMAGESTATUSRESPONSE_INFOENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ImageStatusResponse.InfoEntry)
    })
  ,
  'DESCRIPTOR' : _IMAGESTATUSRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ImageStatusResponse)
  })
_sym_db.RegisterMessage(ImageStatusResponse)
_sym_db.RegisterMessage(ImageStatusResponse.InfoEntry)

AuthConfig = _reflection.GeneratedProtocolMessageType('AuthConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUTHCONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.AuthConfig)
  })
_sym_db.RegisterMessage(AuthConfig)

PullImageRequest = _reflection.GeneratedProtocolMessageType('PullImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _PULLIMAGEREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PullImageRequest)
  })
_sym_db.RegisterMessage(PullImageRequest)

PullImageResponse = _reflection.GeneratedProtocolMessageType('PullImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _PULLIMAGERESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.PullImageResponse)
  })
_sym_db.RegisterMessage(PullImageResponse)

RemoveImageRequest = _reflection.GeneratedProtocolMessageType('RemoveImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEIMAGEREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RemoveImageRequest)
  })
_sym_db.RegisterMessage(RemoveImageRequest)

RemoveImageResponse = _reflection.GeneratedProtocolMessageType('RemoveImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEIMAGERESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RemoveImageResponse)
  })
_sym_db.RegisterMessage(RemoveImageResponse)

NetworkConfig = _reflection.GeneratedProtocolMessageType('NetworkConfig', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKCONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.NetworkConfig)
  })
_sym_db.RegisterMessage(NetworkConfig)

RuntimeConfig = _reflection.GeneratedProtocolMessageType('RuntimeConfig', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMECONFIG,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RuntimeConfig)
  })
_sym_db.RegisterMessage(RuntimeConfig)

UpdateRuntimeConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateRuntimeConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNTIMECONFIGREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.UpdateRuntimeConfigRequest)
  })
_sym_db.RegisterMessage(UpdateRuntimeConfigRequest)

UpdateRuntimeConfigResponse = _reflection.GeneratedProtocolMessageType('UpdateRuntimeConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNTIMECONFIGRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.UpdateRuntimeConfigResponse)
  })
_sym_db.RegisterMessage(UpdateRuntimeConfigResponse)

RuntimeCondition = _reflection.GeneratedProtocolMessageType('RuntimeCondition', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMECONDITION,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RuntimeCondition)
  })
_sym_db.RegisterMessage(RuntimeCondition)

RuntimeStatus = _reflection.GeneratedProtocolMessageType('RuntimeStatus', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMESTATUS,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.RuntimeStatus)
  })
_sym_db.RegisterMessage(RuntimeStatus)

StatusRequest = _reflection.GeneratedProtocolMessageType('StatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATUSREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.StatusRequest)
  })
_sym_db.RegisterMessage(StatusRequest)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), {

  'InfoEntry' : _reflection.GeneratedProtocolMessageType('InfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATUSRESPONSE_INFOENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.StatusResponse.InfoEntry)
    })
  ,
  'DESCRIPTOR' : _STATUSRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.StatusResponse)
  })
_sym_db.RegisterMessage(StatusResponse)
_sym_db.RegisterMessage(StatusResponse.InfoEntry)

ImageFsInfoRequest = _reflection.GeneratedProtocolMessageType('ImageFsInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEFSINFOREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ImageFsInfoRequest)
  })
_sym_db.RegisterMessage(ImageFsInfoRequest)

UInt64Value = _reflection.GeneratedProtocolMessageType('UInt64Value', (_message.Message,), {
  'DESCRIPTOR' : _UINT64VALUE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.UInt64Value)
  })
_sym_db.RegisterMessage(UInt64Value)

FilesystemIdentifier = _reflection.GeneratedProtocolMessageType('FilesystemIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _FILESYSTEMIDENTIFIER,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.FilesystemIdentifier)
  })
_sym_db.RegisterMessage(FilesystemIdentifier)

FilesystemUsage = _reflection.GeneratedProtocolMessageType('FilesystemUsage', (_message.Message,), {
  'DESCRIPTOR' : _FILESYSTEMUSAGE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.FilesystemUsage)
  })
_sym_db.RegisterMessage(FilesystemUsage)

ImageFsInfoResponse = _reflection.GeneratedProtocolMessageType('ImageFsInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEFSINFORESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ImageFsInfoResponse)
  })
_sym_db.RegisterMessage(ImageFsInfoResponse)

ContainerStatsRequest = _reflection.GeneratedProtocolMessageType('ContainerStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATSREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatsRequest)
  })
_sym_db.RegisterMessage(ContainerStatsRequest)

ContainerStatsResponse = _reflection.GeneratedProtocolMessageType('ContainerStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATSRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatsResponse)
  })
_sym_db.RegisterMessage(ContainerStatsResponse)

ListContainerStatsRequest = _reflection.GeneratedProtocolMessageType('ListContainerStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSTATSREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListContainerStatsRequest)
  })
_sym_db.RegisterMessage(ListContainerStatsRequest)

ContainerStatsFilter = _reflection.GeneratedProtocolMessageType('ContainerStatsFilter', (_message.Message,), {

  'LabelSelectorEntry' : _reflection.GeneratedProtocolMessageType('LabelSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERSTATSFILTER_LABELSELECTORENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatsFilter.LabelSelectorEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINERSTATSFILTER,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStatsFilter)
  })
_sym_db.RegisterMessage(ContainerStatsFilter)
_sym_db.RegisterMessage(ContainerStatsFilter.LabelSelectorEntry)

ListContainerStatsResponse = _reflection.GeneratedProtocolMessageType('ListContainerStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONTAINERSTATSRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ListContainerStatsResponse)
  })
_sym_db.RegisterMessage(ListContainerStatsResponse)

ContainerAttributes = _reflection.GeneratedProtocolMessageType('ContainerAttributes', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERATTRIBUTES_LABELSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerAttributes.LabelsEntry)
    })
  ,

  'AnnotationsEntry' : _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERATTRIBUTES_ANNOTATIONSENTRY,
    '__module__' : 'zun.criapi.api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerAttributes.AnnotationsEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINERATTRIBUTES,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerAttributes)
  })
_sym_db.RegisterMessage(ContainerAttributes)
_sym_db.RegisterMessage(ContainerAttributes.LabelsEntry)
_sym_db.RegisterMessage(ContainerAttributes.AnnotationsEntry)

ContainerStats = _reflection.GeneratedProtocolMessageType('ContainerStats', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATS,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ContainerStats)
  })
_sym_db.RegisterMessage(ContainerStats)

CpuUsage = _reflection.GeneratedProtocolMessageType('CpuUsage', (_message.Message,), {
  'DESCRIPTOR' : _CPUUSAGE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.CpuUsage)
  })
_sym_db.RegisterMessage(CpuUsage)

MemoryUsage = _reflection.GeneratedProtocolMessageType('MemoryUsage', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYUSAGE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.MemoryUsage)
  })
_sym_db.RegisterMessage(MemoryUsage)

ReopenContainerLogRequest = _reflection.GeneratedProtocolMessageType('ReopenContainerLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _REOPENCONTAINERLOGREQUEST,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ReopenContainerLogRequest)
  })
_sym_db.RegisterMessage(ReopenContainerLogRequest)

ReopenContainerLogResponse = _reflection.GeneratedProtocolMessageType('ReopenContainerLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _REOPENCONTAINERLOGRESPONSE,
  '__module__' : 'zun.criapi.api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.v1alpha2.ReopenContainerLogResponse)
  })
_sym_db.RegisterMessage(ReopenContainerLogResponse)

_RUNTIMESERVICE = DESCRIPTOR.services_by_name['RuntimeService']
_IMAGESERVICE = DESCRIPTOR.services_by_name['ImageService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z(k8s.io/cri-api/pkg/apis/runtime/v1alpha2\330\341\036\000\200\342\036\001\310\341\036\001\310\342\036\001\340\342\036\001\320\342\036\001\220\343\036\000'
  _LINUXSANDBOXSECURITYCONTEXT.fields_by_name['seccomp_profile_path']._options = None
  _LINUXSANDBOXSECURITYCONTEXT.fields_by_name['seccomp_profile_path']._serialized_options = b'\030\001'
  _LINUXPODSANDBOXCONFIG_SYSCTLSENTRY._options = None
  _LINUXPODSANDBOXCONFIG_SYSCTLSENTRY._serialized_options = b'8\001'
  _PODSANDBOXCONFIG_LABELSENTRY._options = None
  _PODSANDBOXCONFIG_LABELSENTRY._serialized_options = b'8\001'
  _PODSANDBOXCONFIG_ANNOTATIONSENTRY._options = None
  _PODSANDBOXCONFIG_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _PODSANDBOXSTATUS_LABELSENTRY._options = None
  _PODSANDBOXSTATUS_LABELSENTRY._serialized_options = b'8\001'
  _PODSANDBOXSTATUS_ANNOTATIONSENTRY._options = None
  _PODSANDBOXSTATUS_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _PODSANDBOXSTATUSRESPONSE_INFOENTRY._options = None
  _PODSANDBOXSTATUSRESPONSE_INFOENTRY._serialized_options = b'8\001'
  _PODSANDBOXFILTER_LABELSELECTORENTRY._options = None
  _PODSANDBOXFILTER_LABELSELECTORENTRY._serialized_options = b'8\001'
  _PODSANDBOX_LABELSENTRY._options = None
  _PODSANDBOX_LABELSENTRY._serialized_options = b'8\001'
  _PODSANDBOX_ANNOTATIONSENTRY._options = None
  _PODSANDBOX_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _PODSANDBOXSTATSFILTER_LABELSELECTORENTRY._options = None
  _PODSANDBOXSTATSFILTER_LABELSELECTORENTRY._serialized_options = b'8\001'
  _PODSANDBOXATTRIBUTES_LABELSENTRY._options = None
  _PODSANDBOXATTRIBUTES_LABELSENTRY._serialized_options = b'8\001'
  _PODSANDBOXATTRIBUTES_ANNOTATIONSENTRY._options = None
  _PODSANDBOXATTRIBUTES_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _IMAGESPEC_ANNOTATIONSENTRY._options = None
  _IMAGESPEC_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _LINUXCONTAINERRESOURCES_UNIFIEDENTRY._options = None
  _LINUXCONTAINERRESOURCES_UNIFIEDENTRY._serialized_options = b'8\001'
  _LINUXCONTAINERSECURITYCONTEXT.fields_by_name['apparmor_profile']._options = None
  _LINUXCONTAINERSECURITYCONTEXT.fields_by_name['apparmor_profile']._serialized_options = b'\030\001'
  _LINUXCONTAINERSECURITYCONTEXT.fields_by_name['seccomp_profile_path']._options = None
  _LINUXCONTAINERSECURITYCONTEXT.fields_by_name['seccomp_profile_path']._serialized_options = b'\030\001'
  _CONTAINERCONFIG_LABELSENTRY._options = None
  _CONTAINERCONFIG_LABELSENTRY._serialized_options = b'8\001'
  _CONTAINERCONFIG_ANNOTATIONSENTRY._options = None
  _CONTAINERCONFIG_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CONTAINERFILTER_LABELSELECTORENTRY._options = None
  _CONTAINERFILTER_LABELSELECTORENTRY._serialized_options = b'8\001'
  _CONTAINER_LABELSENTRY._options = None
  _CONTAINER_LABELSENTRY._serialized_options = b'8\001'
  _CONTAINER_ANNOTATIONSENTRY._options = None
  _CONTAINER_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CONTAINERSTATUS_LABELSENTRY._options = None
  _CONTAINERSTATUS_LABELSENTRY._serialized_options = b'8\001'
  _CONTAINERSTATUS_ANNOTATIONSENTRY._options = None
  _CONTAINERSTATUS_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CONTAINERSTATUSRESPONSE_INFOENTRY._options = None
  _CONTAINERSTATUSRESPONSE_INFOENTRY._serialized_options = b'8\001'
  _UPDATECONTAINERRESOURCESREQUEST_ANNOTATIONSENTRY._options = None
  _UPDATECONTAINERRESOURCESREQUEST_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _IMAGESTATUSRESPONSE_INFOENTRY._options = None
  _IMAGESTATUSRESPONSE_INFOENTRY._serialized_options = b'8\001'
  _STATUSRESPONSE_INFOENTRY._options = None
  _STATUSRESPONSE_INFOENTRY._serialized_options = b'8\001'
  _CONTAINERSTATSFILTER_LABELSELECTORENTRY._options = None
  _CONTAINERSTATSFILTER_LABELSELECTORENTRY._serialized_options = b'8\001'
  _CONTAINERATTRIBUTES_LABELSENTRY._options = None
  _CONTAINERATTRIBUTES_LABELSENTRY._serialized_options = b'8\001'
  _CONTAINERATTRIBUTES_ANNOTATIONSENTRY._options = None
  _CONTAINERATTRIBUTES_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _PROTOCOL._serialized_start=16556
  _PROTOCOL._serialized_end=16594
  _MOUNTPROPAGATION._serialized_start=16596
  _MOUNTPROPAGATION._serialized_end=16705
  _NAMESPACEMODE._serialized_start=16707
  _NAMESPACEMODE._serialized_end=16768
  _PODSANDBOXSTATE._serialized_start=16770
  _PODSANDBOXSTATE._serialized_end=16828
  _CONTAINERSTATE._serialized_start=16830
  _CONTAINERSTATE._serialized_end=16937
  _VERSIONREQUEST._serialized_start=65
  _VERSIONREQUEST._serialized_end=98
  _VERSIONRESPONSE._serialized_start=100
  _VERSIONRESPONSE._serialized_end=210
  _DNSCONFIG._serialized_start=212
  _DNSCONFIG._serialized_end=275
  _PORTMAPPING._serialized_start=277
  _PORTMAPPING._serialized_end=396
  _MOUNT._serialized_start=399
  _MOUNT._serialized_end=549
  _IDMAPPING._serialized_start=551
  _IDMAPPING._serialized_end=617
  _USERNAMESPACE._serialized_start=620
  _USERNAMESPACE._serialized_end=768
  _NAMESPACEOPTION._serialized_start=771
  _NAMESPACEOPTION._serialized_end=1006
  _INT64VALUE._serialized_start=1008
  _INT64VALUE._serialized_end=1035
  _LINUXSANDBOXSECURITYCONTEXT._serialized_start=1038
  _LINUXSANDBOXSECURITYCONTEXT._serialized_end=1503
  _SECURITYPROFILE._serialized_start=1506
  _SECURITYPROFILE._serialized_end=1681
  _SECURITYPROFILE_PROFILETYPE._serialized_start=1617
  _SECURITYPROFILE_PROFILETYPE._serialized_end=1681
  _LINUXPODSANDBOXCONFIG._serialized_start=1684
  _LINUXPODSANDBOXCONFIG._serialized_end=2045
  _LINUXPODSANDBOXCONFIG_SYSCTLSENTRY._serialized_start=1999
  _LINUXPODSANDBOXCONFIG_SYSCTLSENTRY._serialized_end=2045
  _PODSANDBOXMETADATA._serialized_start=2047
  _PODSANDBOXMETADATA._serialized_end=2130
  _PODSANDBOXCONFIG._serialized_start=2133
  _PODSANDBOXCONFIG._serialized_end=2704
  _PODSANDBOXCONFIG_LABELSENTRY._serialized_start=2607
  _PODSANDBOXCONFIG_LABELSENTRY._serialized_end=2652
  _PODSANDBOXCONFIG_ANNOTATIONSENTRY._serialized_start=2654
  _PODSANDBOXCONFIG_ANNOTATIONSENTRY._serialized_end=2704
  _RUNPODSANDBOXREQUEST._serialized_start=2706
  _RUNPODSANDBOXREQUEST._serialized_end=2805
  _RUNPODSANDBOXRESPONSE._serialized_start=2807
  _RUNPODSANDBOXRESPONSE._serialized_end=2854
  _STOPPODSANDBOXREQUEST._serialized_start=2856
  _STOPPODSANDBOXREQUEST._serialized_end=2903
  _STOPPODSANDBOXRESPONSE._serialized_start=2905
  _STOPPODSANDBOXRESPONSE._serialized_end=2929
  _REMOVEPODSANDBOXREQUEST._serialized_start=2931
  _REMOVEPODSANDBOXREQUEST._serialized_end=2980
  _REMOVEPODSANDBOXRESPONSE._serialized_start=2982
  _REMOVEPODSANDBOXRESPONSE._serialized_end=3008
  _PODSANDBOXSTATUSREQUEST._serialized_start=3010
  _PODSANDBOXSTATUSREQUEST._serialized_end=3076
  _PODIP._serialized_start=3078
  _PODIP._serialized_end=3097
  _PODSANDBOXNETWORKSTATUS._serialized_start=3099
  _PODSANDBOXNETWORKSTATUS._serialized_end=3185
  _NAMESPACE._serialized_start=3187
  _NAMESPACE._serialized_end=3250
  _LINUXPODSANDBOXSTATUS._serialized_start=3252
  _LINUXPODSANDBOXSTATUS._serialized_end=3324
  _PODSANDBOXSTATUS._serialized_start=3327
  _PODSANDBOXSTATUS._serialized_end=3861
  _PODSANDBOXSTATUS_LABELSENTRY._serialized_start=2607
  _PODSANDBOXSTATUS_LABELSENTRY._serialized_end=2652
  _PODSANDBOXSTATUS_ANNOTATIONSENTRY._serialized_start=2654
  _PODSANDBOXSTATUS_ANNOTATIONSENTRY._serialized_end=2704
  _PODSANDBOXSTATUSRESPONSE._serialized_start=3864
  _PODSANDBOXSTATUSRESPONSE._serialized_end=4055
  _PODSANDBOXSTATUSRESPONSE_INFOENTRY._serialized_start=4012
  _PODSANDBOXSTATUSRESPONSE_INFOENTRY._serialized_end=4055
  _PODSANDBOXSTATEVALUE._serialized_start=4057
  _PODSANDBOXSTATEVALUE._serialized_end=4129
  _PODSANDBOXFILTER._serialized_start=4132
  _PODSANDBOXFILTER._serialized_end=4350
  _PODSANDBOXFILTER_LABELSELECTORENTRY._serialized_start=4298
  _PODSANDBOXFILTER_LABELSELECTORENTRY._serialized_end=4350
  _LISTPODSANDBOXREQUEST._serialized_start=4352
  _LISTPODSANDBOXREQUEST._serialized_end=4427
  _PODSANDBOX._serialized_start=4430
  _PODSANDBOX._serialized_end=4830
  _PODSANDBOX_LABELSENTRY._serialized_start=2607
  _PODSANDBOX_LABELSENTRY._serialized_end=2652
  _PODSANDBOX_ANNOTATIONSENTRY._serialized_start=2654
  _PODSANDBOX_ANNOTATIONSENTRY._serialized_end=2704
  _LISTPODSANDBOXRESPONSE._serialized_start=4832
  _LISTPODSANDBOXRESPONSE._serialized_end=4901
  _PODSANDBOXSTATSREQUEST._serialized_start=4903
  _PODSANDBOXSTATSREQUEST._serialized_end=4951
  _PODSANDBOXSTATSRESPONSE._serialized_start=4953
  _PODSANDBOXSTATSRESPONSE._serialized_end=5028
  _PODSANDBOXSTATSFILTER._serialized_start=5031
  _PODSANDBOXSTATSFILTER._serialized_end=5204
  _PODSANDBOXSTATSFILTER_LABELSELECTORENTRY._serialized_start=4298
  _PODSANDBOXSTATSFILTER_LABELSELECTORENTRY._serialized_end=4350
  _LISTPODSANDBOXSTATSREQUEST._serialized_start=5206
  _LISTPODSANDBOXSTATSREQUEST._serialized_end=5291
  _LISTPODSANDBOXSTATSRESPONSE._serialized_start=5293
  _LISTPODSANDBOXSTATSRESPONSE._serialized_end=5372
  _PODSANDBOXATTRIBUTES._serialized_start=5375
  _PODSANDBOXATTRIBUTES._serialized_end=5710
  _PODSANDBOXATTRIBUTES_LABELSENTRY._serialized_start=2607
  _PODSANDBOXATTRIBUTES_LABELSENTRY._serialized_end=2652
  _PODSANDBOXATTRIBUTES_ANNOTATIONSENTRY._serialized_start=2654
  _PODSANDBOXATTRIBUTES_ANNOTATIONSENTRY._serialized_end=2704
  _PODSANDBOXSTATS._serialized_start=5713
  _PODSANDBOXSTATS._serialized_end=5904
  _LINUXPODSANDBOXSTATS._serialized_start=5907
  _LINUXPODSANDBOXSTATS._serialized_end=6169
  _WINDOWSPODSANDBOXSTATS._serialized_start=6171
  _WINDOWSPODSANDBOXSTATS._serialized_end=6195
  _NETWORKUSAGE._serialized_start=6198
  _NETWORKUSAGE._serialized_end=6360
  _NETWORKINTERFACEUSAGE._serialized_start=6363
  _NETWORKINTERFACEUSAGE._serialized_end=6598
  _PROCESSUSAGE._serialized_start=6600
  _PROCESSUSAGE._serialized_end=6687
  _IMAGESPEC._serialized_start=6690
  _IMAGESPEC._serialized_end=6835
  _IMAGESPEC_ANNOTATIONSENTRY._serialized_start=2654
  _IMAGESPEC_ANNOTATIONSENTRY._serialized_end=2704
  _KEYVALUE._serialized_start=6837
  _KEYVALUE._serialized_end=6875
  _LINUXCONTAINERRESOURCES._serialized_start=6878
  _LINUXCONTAINERRESOURCES._serialized_end=7273
  _LINUXCONTAINERRESOURCES_UNIFIEDENTRY._serialized_start=7227
  _LINUXCONTAINERRESOURCES_UNIFIEDENTRY._serialized_end=7273
  _HUGEPAGELIMIT._serialized_start=7275
  _HUGEPAGELIMIT._serialized_end=7324
  _SELINUXOPTION._serialized_start=7326
  _SELINUXOPTION._serialized_end=7398
  _CAPABILITY._serialized_start=7400
  _CAPABILITY._serialized_end=7499
  _LINUXCONTAINERSECURITYCONTEXT._serialized_start=7502
  _LINUXCONTAINERSECURITYCONTEXT._serialized_end=8144
  _LINUXCONTAINERCONFIG._serialized_start=8147
  _LINUXCONTAINERCONFIG._serialized_end=8306
  _WINDOWSSANDBOXSECURITYCONTEXT._serialized_start=8308
  _WINDOWSSANDBOXSECURITYCONTEXT._serialized_end=8411
  _WINDOWSPODSANDBOXCONFIG._serialized_start=8413
  _WINDOWSPODSANDBOXCONFIG._serialized_end=8513
  _WINDOWSCONTAINERSECURITYCONTEXT._serialized_start=8515
  _WINDOWSCONTAINERSECURITYCONTEXT._serialized_end=8620
  _WINDOWSCONTAINERCONFIG._serialized_start=8623
  _WINDOWSCONTAINERCONFIG._serialized_end=8788
  _WINDOWSCONTAINERRESOURCES._serialized_start=8791
  _WINDOWSCONTAINERRESOURCES._serialized_end=8939
  _CONTAINERMETADATA._serialized_start=8941
  _CONTAINERMETADATA._serialized_end=8991
  _DEVICE._serialized_start=8993
  _DEVICE._serialized_end=9065
  _CONTAINERCONFIG._serialized_start=9068
  _CONTAINERCONFIG._serialized_end=9777
  _CONTAINERCONFIG_LABELSENTRY._serialized_start=2607
  _CONTAINERCONFIG_LABELSENTRY._serialized_end=2652
  _CONTAINERCONFIG_ANNOTATIONSENTRY._serialized_start=2654
  _CONTAINERCONFIG_ANNOTATIONSENTRY._serialized_end=2704
  _CREATECONTAINERREQUEST._serialized_start=9780
  _CREATECONTAINERREQUEST._serialized_end=9939
  _CREATECONTAINERRESPONSE._serialized_start=9941
  _CREATECONTAINERRESPONSE._serialized_end=9988
  _STARTCONTAINERREQUEST._serialized_start=9990
  _STARTCONTAINERREQUEST._serialized_end=10035
  _STARTCONTAINERRESPONSE._serialized_start=10037
  _STARTCONTAINERRESPONSE._serialized_end=10061
  _STOPCONTAINERREQUEST._serialized_start=10063
  _STOPCONTAINERREQUEST._serialized_end=10124
  _STOPCONTAINERRESPONSE._serialized_start=10126
  _STOPCONTAINERRESPONSE._serialized_end=10149
  _REMOVECONTAINERREQUEST._serialized_start=10151
  _REMOVECONTAINERREQUEST._serialized_end=10197
  _REMOVECONTAINERRESPONSE._serialized_start=10199
  _REMOVECONTAINERRESPONSE._serialized_end=10224
  _CONTAINERSTATEVALUE._serialized_start=10226
  _CONTAINERSTATEVALUE._serialized_end=10296
  _CONTAINERFILTER._serialized_start=10299
  _CONTAINERFILTER._serialized_end=10538
  _CONTAINERFILTER_LABELSELECTORENTRY._serialized_start=4298
  _CONTAINERFILTER_LABELSELECTORENTRY._serialized_end=4350
  _LISTCONTAINERSREQUEST._serialized_start=10540
  _LISTCONTAINERSREQUEST._serialized_end=10614
  _CONTAINER._serialized_start=10617
  _CONTAINER._serialized_end=11074
  _CONTAINER_LABELSENTRY._serialized_start=2607
  _CONTAINER_LABELSENTRY._serialized_end=2652
  _CONTAINER_ANNOTATIONSENTRY._serialized_start=2654
  _CONTAINER_ANNOTATIONSENTRY._serialized_end=2704
  _LISTCONTAINERSRESPONSE._serialized_start=11076
  _LISTCONTAINERSRESPONSE._serialized_end=11149
  _CONTAINERSTATUSREQUEST._serialized_start=11151
  _CONTAINERSTATUSREQUEST._serialized_end=11214
  _CONTAINERSTATUS._serialized_start=11217
  _CONTAINERSTATUS._serialized_end=11820
  _CONTAINERSTATUS_LABELSENTRY._serialized_start=2607
  _CONTAINERSTATUS_LABELSENTRY._serialized_end=2652
  _CONTAINERSTATUS_ANNOTATIONSENTRY._serialized_start=2654
  _CONTAINERSTATUS_ANNOTATIONSENTRY._serialized_end=2704
  _CONTAINERSTATUSRESPONSE._serialized_start=11823
  _CONTAINERSTATUSRESPONSE._serialized_end=12011
  _CONTAINERSTATUSRESPONSE_INFOENTRY._serialized_start=4012
  _CONTAINERSTATUSRESPONSE_INFOENTRY._serialized_end=4055
  _UPDATECONTAINERRESOURCESREQUEST._serialized_start=12014
  _UPDATECONTAINERRESOURCESREQUEST._serialized_end=12330
  _UPDATECONTAINERRESOURCESREQUEST_ANNOTATIONSENTRY._serialized_start=2654
  _UPDATECONTAINERRESOURCESREQUEST_ANNOTATIONSENTRY._serialized_end=2704
  _UPDATECONTAINERRESOURCESRESPONSE._serialized_start=12332
  _UPDATECONTAINERRESOURCESRESPONSE._serialized_end=12366
  _EXECSYNCREQUEST._serialized_start=12368
  _EXECSYNCREQUEST._serialized_end=12437
  _EXECSYNCRESPONSE._serialized_start=12439
  _EXECSYNCRESPONSE._serialized_end=12508
  _EXECREQUEST._serialized_start=12510
  _EXECREQUEST._serialized_end=12618
  _EXECRESPONSE._serialized_start=12620
  _EXECRESPONSE._serialized_end=12647
  _ATTACHREQUEST._serialized_start=12649
  _ATTACHREQUEST._serialized_end=12746
  _ATTACHRESPONSE._serialized_start=12748
  _ATTACHRESPONSE._serialized_end=12777
  _PORTFORWARDREQUEST._serialized_start=12779
  _PORTFORWARDREQUEST._serialized_end=12837
  _PORTFORWARDRESPONSE._serialized_start=12839
  _PORTFORWARDRESPONSE._serialized_end=12873
  _IMAGEFILTER._serialized_start=12875
  _IMAGEFILTER._serialized_end=12932
  _LISTIMAGESREQUEST._serialized_start=12934
  _LISTIMAGESREQUEST._serialized_end=13000
  _IMAGE._serialized_start=13003
  _IMAGE._serialized_end=13197
  _LISTIMAGESRESPONSE._serialized_start=13199
  _LISTIMAGESRESPONSE._serialized_end=13260
  _IMAGESTATUSREQUEST._serialized_start=13262
  _IMAGESTATUSREQUEST._serialized_end=13343
  _IMAGESTATUSRESPONSE._serialized_start=13346
  _IMAGESTATUSRESPONSE._serialized_end=13515
  _IMAGESTATUSRESPONSE_INFOENTRY._serialized_start=4012
  _IMAGESTATUSRESPONSE_INFOENTRY._serialized_end=4055
  _AUTHCONFIG._serialized_start=13518
  _AUTHCONFIG._serialized_end=13652
  _PULLIMAGEREQUEST._serialized_start=13655
  _PULLIMAGEREQUEST._serialized_end=13821
  _PULLIMAGERESPONSE._serialized_start=13823
  _PULLIMAGERESPONSE._serialized_end=13861
  _REMOVEIMAGEREQUEST._serialized_start=13863
  _REMOVEIMAGEREQUEST._serialized_end=13927
  _REMOVEIMAGERESPONSE._serialized_start=13929
  _REMOVEIMAGERESPONSE._serialized_end=13950
  _NETWORKCONFIG._serialized_start=13952
  _NETWORKCONFIG._serialized_end=13985
  _RUNTIMECONFIG._serialized_start=13987
  _RUNTIMECONFIG._serialized_end=14059
  _UPDATERUNTIMECONFIGREQUEST._serialized_start=14061
  _UPDATERUNTIMECONFIGREQUEST._serialized_end=14146
  _UPDATERUNTIMECONFIGRESPONSE._serialized_start=14148
  _UPDATERUNTIMECONFIGRESPONSE._serialized_end=14177
  _RUNTIMECONDITION._serialized_start=14179
  _RUNTIMECONDITION._serialized_end=14260
  _RUNTIMESTATUS._serialized_start=14262
  _RUNTIMESTATUS._serialized_end=14333
  _STATUSREQUEST._serialized_start=14335
  _STATUSREQUEST._serialized_end=14367
  _STATUSRESPONSE._serialized_start=14370
  _STATUSRESPONSE._serialized_end=14538
  _STATUSRESPONSE_INFOENTRY._serialized_start=4012
  _STATUSRESPONSE_INFOENTRY._serialized_end=4055
  _IMAGEFSINFOREQUEST._serialized_start=14540
  _IMAGEFSINFOREQUEST._serialized_end=14560
  _UINT64VALUE._serialized_start=14562
  _UINT64VALUE._serialized_end=14590
  _FILESYSTEMIDENTIFIER._serialized_start=14592
  _FILESYSTEMIDENTIFIER._serialized_end=14634
  _FILESYSTEMUSAGE._serialized_start=14637
  _FILESYSTEMUSAGE._serialized_end=14831
  _IMAGEFSINFORESPONSE._serialized_start=14833
  _IMAGEFSINFORESPONSE._serialized_end=14916
  _CONTAINERSTATSREQUEST._serialized_start=14918
  _CONTAINERSTATSREQUEST._serialized_end=14963
  _CONTAINERSTATSRESPONSE._serialized_start=14965
  _CONTAINERSTATSRESPONSE._serialized_end=15038
  _LISTCONTAINERSTATSREQUEST._serialized_start=15040
  _LISTCONTAINERSTATSREQUEST._serialized_end=15123
  _CONTAINERSTATSFILTER._serialized_start=15126
  _CONTAINERSTATSFILTER._serialized_end=15321
  _CONTAINERSTATSFILTER_LABELSELECTORENTRY._serialized_start=4298
  _CONTAINERSTATSFILTER_LABELSELECTORENTRY._serialized_end=4350
  _LISTCONTAINERSTATSRESPONSE._serialized_start=15323
  _LISTCONTAINERSTATSRESPONSE._serialized_end=15400
  _CONTAINERATTRIBUTES._serialized_start=15403
  _CONTAINERATTRIBUTES._serialized_end=15734
  _CONTAINERATTRIBUTES_LABELSENTRY._serialized_start=2607
  _CONTAINERATTRIBUTES_LABELSENTRY._serialized_end=2652
  _CONTAINERATTRIBUTES_ANNOTATIONSENTRY._serialized_start=2654
  _CONTAINERATTRIBUTES_ANNOTATIONSENTRY._serialized_end=2704
  _CONTAINERSTATS._serialized_start=15737
  _CONTAINERSTATS._serialized_end=15959
  _CPUUSAGE._serialized_start=15962
  _CPUUSAGE._serialized_end=16112
  _MEMORYUSAGE._serialized_start=16115
  _MEMORYUSAGE._serialized_end=16473
  _REOPENCONTAINERLOGREQUEST._serialized_start=16475
  _REOPENCONTAINERLOGREQUEST._serialized_end=16524
  _REOPENCONTAINERLOGRESPONSE._serialized_start=16526
  _REOPENCONTAINERLOGRESPONSE._serialized_end=16554
  _RUNTIMESERVICE._serialized_start=16940
  _RUNTIMESERVICE._serialized_end=19405
  _IMAGESERVICE._serialized_start=19408
  _IMAGESERVICE._serialized_end=19883
# @@protoc_insertion_point(module_scope)
